#!/usr/bin/python3
from PySide2 import QtCore, QtGui, QtWidgets

class Ui_main_window(object):
    def setupUi(self, main_window):
        main_window.setObjectName("main_window")
        main_window.resize(1572, 1154)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icon/nounproject/maxim_kulikov/cow_flower_square.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        main_window.setWindowIcon(icon)
        main_window.setStyleSheet("/* ------------------( SYNOPSIS                          )---------------------\n"
"Root stylesheet for this application, attached to the main window widget from\n"
"Qt [Creator|Designer] to preserve the WYSIWYG metaphor.\n"
"\n"
"---------------------( SEE ALSO                          )---------------------\n"
"* https://doc.qt.io/qt-5/stylesheet-syntax.html\n"
"  Reference documentation for Qt 5 stylesheets.\n"
"* http://doc.qt.io/qt-5/stylesheet-syntax.html#conflict-resolution\n"
"  \"Conflict Resolution\" subsection of the prior documentation, arguably the most\n"
"  significant and least understood such subsection.\n"
"* http://doc.qt.io/qt-5/stylesheet-reference.html#list-of-sub-controls\n"
"  Reference documentation for Qt 5 stylesheet pseudo-states and subcontrols.\n"
"*/\n"
"\n"
"/* FIXME: Report the QSS bugs listed below to the Qt issue tracker, please.\n"
" */\n"
"\n"
"/*!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n"
" * CAUTION: *ORDER IS SIGNIFICANT.* The following styles are intentionally\n"
" * listed in order of increasing depth. While conflict resolution in QSS is\n"
" * highly non-trivial and exceeds the scope of this stylesheet to reasonably\n"
" * document, subsequently listed styles mostly take precedence over previously\n"
" * listed styles. (Mostly. All else being equal. Which it never is.)\n"
" *\n"
" * Additionally, note that QSS suffers numerous subtle breaking bugs under even\n"
" * recent stable releases of Qt. These include:\n"
" *\n"
" * * Promoted widget types (e.g., \"QBetseeSimConfStackedWidget\") should be\n"
" *   avoided in favour of stock widget types (e.g., \"QStackedWidget\"). Due to\n"
" *   outstanding issues in Qt (Creator|Designer), styles selected via promoted\n"
" *   widget types are displayed at runtime but *NOT* from within Qt\n"
" *   (Creator|Designer) -- defeating the WYSIWYG intention of using Qt\n"
" *   (Creator|Designer) in the first place.\n"
" * * \"QScrollArea\" and \"QTabWidget\" children should be selected with the \" \"\n"
" *   descendent selector rather than the \">\" child selector (e.g.,\n"
" *   \"QScrollArea QGrouBox\" rather than \"QScrollArea > QGrouBox\"). While the\n"
" *   latter is less ambiguous and hence preferable in the general case, QSS\n"
" *   ignores *ALL* selectors of the form \"QScrollArea >\". Why? Just because.\n"
" *!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n"
" */\n"
"\n"
"/* ..................{ GENERAL                           }.....................\n"
" * Styles generally applicable to all widgets of a particular type.\n"
" */\n"
"\n"
"/* Group box title but *NOT* child widgets of a group box.\n"
" *\n"
" * To properly account for nesting depth, depth-specific font sizes are styled\n"
" * by explicitly selecting group box titles at all possible nesting depths\n"
" * employed by this application below. Needless to say, QSS is less than ideal.\n"
" */\n"
"QGroupBox {\n"
"    font-weight: bold;\n"
"}\n"
"\n"
"/* ..................{ GENERAL ~ property                }.....................\n"
" * Styles generally applicable to all widgets of a particular type with an\n"
" * arbitrary property set to a particular value.\n"
" */\n"
"\n"
"/* Check box with *NO* corresponding text.\n"
" */\n"
"QCheckBox[text=\"\"] {\n"
"    font-size: 0pt;\n"
"    spacing: 0px;\n"
"}\n"
"\n"
"/* ..................{ GENERAL ~ title                   }.....................\n"
" * Styles applicable to widget titles or the equivalent thereof for the widget\n"
" * in question (e.g., column headers for tree widgets) in a general manner.\n"
" */\n"
"\n"
"/* Widget title of either a:\n"
" *\n"
" * * Stacked page.\n"
" * * Currently selected tab.\n"
" * * Top-level tree widget column headers.\n"
" *\n"
" * Due to outstanding QSS issues, note that font properties (e.g., size,\n"
" * weight) cannot be reliably set via the \"::tab\" subcontrol selected here but\n"
" * *MUST* instead be set on the \"QTabWidget > QTabBar\" itself. Attempting to\n"
" * set this font size via that subcontrol prevents Qt from resizing tabs to\n"
" * accomodate this larger size, resulting in \"cut off\" and hence illegible tab\n"
" * titles.\n"
" *\n"
" * This is an outstanding issue in the Qt issue tracker at:\n"
" *     https://bugreports.qt.io/browse/QTBUG-8209\n"
" */\n"
"QStackedWidget#sim_conf_stack > QWidget > QGroupBox,\n"
"QTabWidget#sim_tab > QTabBar,\n"
"QTreeWidget#sim_conf_tree QHeaderView::section {\n"
"    font-size: 14pt;\n"
"\n"
"    /* Ideally, *ONLY* the currently selected tab would be emboldened. Sadly,\n"
"     * the \":selected\" pseudo-class only applies to the \"::tab\" subcontrol\n"
"     * (e.g., \"QTabWidget#sim_tab > QTabBar::tab:selected\"). However, the\n"
"     * latter and hence the former is unusable for the reasons discussed above.\n"
"     */\n"
"    font-weight: bold;\n"
"}\n"
"\n"
"\n"
"/* ..................{ SIM ~ stack|tab                   }.....................\n"
" * Styles applicable to stacked and tab widgets for simulation configuration.\n"
" */\n"
"\n"
"/* ..................{ SIM ~ stack|tab : group : widget  }.....................\n"
" * Note that pages of both stacked and tab widgets *MUST* be selected via the\n"
" * dynamic \"is_page\" property manually enabled for these pages. For unknown\n"
" * reasons (presumably reducing to subtle bugs in Qt\'s CSS selector handling),\n"
" * tab widget pages are selectable by the less useful \" \" descendant selector\n"
" * but *NOT* by the more useful \">\" child selector; ergo, such pages are\n"
" * unambiguously selectable only by dynamic properties. While stacked widget\n"
" * pages are technically selectable by either selector, doing so is complicated\n"
" * by the observation that \"QStackedWidget#sim_conf_stack > QWidget > QGroupBox\"\n"
" * actually selects such a page rather than a group box within such a page;\n"
" * ergo, such pages are best selected by dynamic properties as well. For\n"
" * orthogonality, these pages are all selectable by the following selector:\n"
" *\n"
" *     QWidget[is_page=\"true\"]\n"
" *\n"
" * Note also that, if QSS supported the CSS4-specific :matches() pseudo-class:\n"
" *\n"
" *     # Multiline selectors resembling the following...\n"
" *     QStackedWidget#sim_conf > QWidget > QGroupBox,\n"
" *     QTabWidget#sim_cmd > QWidget > QGroupBox {\n"
" *\n"
" *     # ...would be reducible to one-liner selectors resembling the following.\n"
" *     :matches(QStackedWidget#sim_conf, QTabWidget#sim_cmd) > QWidget > QGroupBox {\n"
" *\n"
" * Sadly, QSS currently only supports CSS2, which provides no comparable means\n"
" * of grouping the \", \" or operator to have higher precedence than the \">\"\n"
" * descendent selector.\n"
" */\n"
"\n"
"/* Widgets either:\n"
" *\n"
" * * Direct children of a stacked page or tabbed tab.\n"
" * * At any depth of a top-level group box in a stacked page or tabbed tab.\n"
" */\n"
"QStackedWidget#sim_conf_stack QWidget[is_page=\"true\"] > QWidget,\n"
"QTabWidget#sim_tab            QWidget[is_page=\"true\"] > QWidget,\n"
"QStackedWidget#sim_conf_stack QWidget[is_page=\"true\"] > QGroupBox QWidget,\n"
"QTabWidget#sim_tab            QWidget[is_page=\"true\"] > QGroupBox QWidget {\n"
"    font-size: 12pt;\n"
"}\n"
"\n"
"\n"
"/* Widgets at any depth of either a:\n"
" *\n"
" * * Second-level group in a stacked page or tabbed tab.\n"
" * * Container widget enabling the \"is_group\" dynamic property (effectively\n"
" *   acting as a second-level group) in a first-level group in a tabbed tab.\n"
" */\n"
"QStackedWidget#sim_conf_stack QWidget[is_page=\"true\"] > QGroupBox > QGroupBox QWidget,\n"
"QTabWidget#sim_tab            QWidget[is_page=\"true\"] > QGroupBox > QGroupBox QWidget,\n"
"QTabWidget#sim_tab            QWidget[is_page=\"true\"] > QGroupBox > QWidget[is_group=\"true\"] QWidget {\n"
"    font-size: 11pt;\n"
"}\n"
"\n"
"\n"
"/* Widgets at any depth of a third group in a stacked page or tabbed tab.\n"
" */\n"
"QStackedWidget#sim_conf_stack QWidget[is_page=\"true\"] > QGroupBox > QGroupBox > QGroupBox QWidget,\n"
"QTabWidget#sim_tab            QWidget[is_page=\"true\"] > QGroupBox > QGroupBox > QGroupBox QWidget {\n"
"    font-size: 10pt;\n"
"}\n"
"\n"
"/* ..................{ SIM ~ stack|tab : group           }.....................\n"
" * To ensure that group box selectors take precedence over selectors intended\n"
" * to be applicable *ONLY* to the children of these selectors, the former are\n"
" * intentionally specified *AFTER* rather than *BEFORE* the latter. Sadly, Qt\n"
" * documentation explicitly admits that selectors of greater class specificity\n"
" * (e.g., \"QGroupBox\") take precedence over those of lesser class specificity\n"
" * (e.g., \"QWidget\"). Ergo, we do this the hard way. Always the hard way.\n"
" */\n"
"\n"
"/* Top-level group box in a stacked page or tabbed tab. */\n"
"QStackedWidget#sim_conf_stack QWidget[is_page=\"true\"] > QGroupBox,\n"
"QTabWidget#sim_tab            QWidget[is_page=\"true\"] > QGroupBox {\n"
"    font-size: 13pt;\n"
"}\n"
"\n"
"\n"
"/* Second-level group box in a stacked page or tabbed tab. */\n"
"QStackedWidget#sim_conf_stack QWidget[is_page=\"true\"] > QGroupBox > QGroupBox,\n"
"QTabWidget#sim_tab            QWidget[is_page=\"true\"] > QGroupBox > QGroupBox {\n"
"    font-size: 12pt;\n"
"}\n"
"\n"
"\n"
"/* Third-level group box in a stacked page or tabbed tab. */\n"
"QStackedWidget#sim_conf_stack QWidget[is_page=\"true\"] > QGroupBox > QGroupBox > QGroupBox,\n"
"QTabWidget#sim_tab            QWidget[is_page=\"true\"] > QGroupBox > QGroupBox > QGroupBox {\n"
"    font-size: 11pt;\n"
"}\n"
"\n"
"/* ..................{ WIDGET ~ name                     }.....................\n"
" * Styles applicable to specific widgets identified by their globally unique\n"
" * object names, defined last to ensure their precedence over general-purpose\n"
" * styles defined above.\n"
" */\n"
"\n"
"/* Top-level logging widget. */\n"
"QPlainTextEdit#log_box {\n"
"    font: 10pt \"Monospace\";\n"
"}\n"
"\n"
"\n"
"/* Top-level tree widget. */\n"
"QTreeWidget#sim_conf_tree {\n"
"    /* Ideally, the following font properties would be applied to the items of\n"
"     * this tree rather than this tree itself. Sadly, Qt currently ignores all\n"
"     * attempts to do so via the \"::item\" selector: e.g.,\n"
"     *\n"
"     *     # This is ignored.\n"
"     *     QTreeWidget#sim_conf_tree::item { font-weight: bold }\n"
"     *\n"
"     * Why? Because:\n"
"     *\n"
"     *     Is there a way to change the font-weight (or font-size minimum) of\n"
"     *     the selected item in QListWidget? No, as such font style option\n"
"     *     applies to QWidgets, so you could apply the font (or other like\n"
"     *     font-size) style option to the entire QWidget (QListWidget in this\n"
"     *     case) and not to special behavior of a derived QWidget i.e.\n"
"     *     QListWidget\'s selection item.\n"
"     */\n"
"    font-size: 12pt;\n"
"    qproperty-indentation: 26;\n"
"}\n"
"")
        main_window.setUnifiedTitleAndToolBarOnMac(True)
        self.centralWidget = QtWidgets.QWidget(main_window)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.centralWidget.sizePolicy().hasHeightForWidth())
        self.centralWidget.setSizePolicy(sizePolicy)
        self.centralWidget.setObjectName("centralWidget")
        self.gridLayout = QtWidgets.QGridLayout(self.centralWidget)
        self.gridLayout.setObjectName("gridLayout")
        self.sim_conf_tree_frame = QtWidgets.QFrame(self.centralWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(4)
        sizePolicy.setHeightForWidth(self.sim_conf_tree_frame.sizePolicy().hasHeightForWidth())
        self.sim_conf_tree_frame.setSizePolicy(sizePolicy)
        self.sim_conf_tree_frame.setMinimumSize(QtCore.QSize(0, 0))
        self.sim_conf_tree_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.sim_conf_tree_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.sim_conf_tree_frame.setObjectName("sim_conf_tree_frame")
        self.verticalLayout_21 = QtWidgets.QVBoxLayout(self.sim_conf_tree_frame)
        self.verticalLayout_21.setSpacing(0)
        self.verticalLayout_21.setObjectName("verticalLayout_21")
        self.sim_conf_tree = QBetseeSimConfTreeWidget(self.sim_conf_tree_frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.sim_conf_tree.sizePolicy().hasHeightForWidth())
        self.sim_conf_tree.setSizePolicy(sizePolicy)
        self.sim_conf_tree.setRootIsDecorated(True)
        self.sim_conf_tree.setUniformRowHeights(False)
        self.sim_conf_tree.setItemsExpandable(True)
        self.sim_conf_tree.setObjectName("sim_conf_tree")
        item_0 = QtWidgets.QTreeWidgetItem(self.sim_conf_tree)
        icon1 = QtGui.QIcon()
        icon1.addFile("://icon/betsee/chemical.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_0.setIcon(0, icon1)
        item_1 = QtWidgets.QTreeWidgetItem(item_0)
        icon2 = QtGui.QIcon()
        icon2.addFile("://icon/open_iconic/aperture.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_1.setIcon(0, icon2)
        item_0 = QtWidgets.QTreeWidgetItem(self.sim_conf_tree)
        icon3 = QtGui.QIcon()
        icon3.addFile("://icon/open_iconic/clock.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_0.setIcon(0, icon3)
        item_0 = QtWidgets.QTreeWidgetItem(self.sim_conf_tree)
        icon4 = QtGui.QIcon()
        icon4.addFile("://icon/entypo+/sports-club.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_0.setIcon(0, icon4)
        item_0 = QtWidgets.QTreeWidgetItem(self.sim_conf_tree)
        icon5 = QtGui.QIcon()
        icon5.addFile(":/icon/open_iconic/folder.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_0.setIcon(0, icon5)
        item_0 = QtWidgets.QTreeWidgetItem(self.sim_conf_tree)
        item_0 = QtWidgets.QTreeWidgetItem(self.sim_conf_tree)
        icon6 = QtGui.QIcon()
        icon6.addFile("://icon/open_iconic/bolt.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_0.setIcon(0, icon6)
        item_0 = QtWidgets.QTreeWidgetItem(self.sim_conf_tree)
        icon7 = QtGui.QIcon()
        icon7.addFile("://icon/open_iconic/eyedropper.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_0.setIcon(0, icon7)
        item_0 = QtWidgets.QTreeWidgetItem(self.sim_conf_tree)
        icon8 = QtGui.QIcon()
        icon8.addFile("://icon/open_iconic/share.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_0.setIcon(0, icon8)
        item_0 = QtWidgets.QTreeWidgetItem(self.sim_conf_tree)
        icon9 = QtGui.QIcon()
        icon9.addFile("://icon/betsee/dna.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_0.setIcon(0, icon9)
        item_1 = QtWidgets.QTreeWidgetItem(item_0)
        item_1 = QtWidgets.QTreeWidgetItem(item_0)
        item_1 = QtWidgets.QTreeWidgetItem(item_0)
        item_1 = QtWidgets.QTreeWidgetItem(item_0)
        item_1 = QtWidgets.QTreeWidgetItem(item_0)
        item_0 = QtWidgets.QTreeWidgetItem(self.sim_conf_tree)
        icon10 = QtGui.QIcon()
        icon10.addFile("://icon/betsee/planet.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_0.setIcon(0, icon10)
        item_0 = QtWidgets.QTreeWidgetItem(self.sim_conf_tree)
        icon11 = QtGui.QIcon()
        icon11.addFile("://icon/open_iconic/wrench.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_0.setIcon(0, icon11)
        item_0 = QtWidgets.QTreeWidgetItem(self.sim_conf_tree)
        icon12 = QtGui.QIcon()
        icon12.addFile("://icon/betsee/advanced.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_0.setIcon(0, icon12)
        item_0 = QtWidgets.QTreeWidgetItem(self.sim_conf_tree)
        icon13 = QtGui.QIcon()
        icon13.addFile("://icon/open_iconic/bars.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_0.setIcon(0, icon13)
        item_0 = QtWidgets.QTreeWidgetItem(self.sim_conf_tree)
        icon14 = QtGui.QIcon()
        icon14.addFile("://icon/open_iconic/list.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_0.setIcon(0, icon14)
        item_0 = QtWidgets.QTreeWidgetItem(self.sim_conf_tree)
        icon15 = QtGui.QIcon()
        icon15.addFile("://icon/betsee/lineplot.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_0.setIcon(0, icon15)
        item_0 = QtWidgets.QTreeWidgetItem(self.sim_conf_tree)
        icon16 = QtGui.QIcon()
        icon16.addFile("://icon/open_iconic/image.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_0.setIcon(0, icon16)
        item_0 = QtWidgets.QTreeWidgetItem(self.sim_conf_tree)
        icon17 = QtGui.QIcon()
        icon17.addFile("://icon/open_iconic/movie.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_0.setIcon(0, icon17)
        self.verticalLayout_21.addWidget(self.sim_conf_tree)
        self.sim_conf_tree_toolbar_frame = QtWidgets.QFrame(self.sim_conf_tree_frame)
        self.sim_conf_tree_toolbar_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.sim_conf_tree_toolbar_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.sim_conf_tree_toolbar_frame.setObjectName("sim_conf_tree_toolbar_frame")
        self.verticalLayout_20 = QtWidgets.QVBoxLayout(self.sim_conf_tree_toolbar_frame)
        self.verticalLayout_20.setSpacing(0)
        self.verticalLayout_20.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_20.setObjectName("verticalLayout_20")
        self.sim_conf_tree_toolbar = QtWidgets.QToolBar(self.sim_conf_tree_toolbar_frame)
        self.sim_conf_tree_toolbar.setIconSize(QtCore.QSize(16, 16))
        self.sim_conf_tree_toolbar.setFloatable(False)
        self.sim_conf_tree_toolbar.setObjectName("sim_conf_tree_toolbar")
        self.verticalLayout_20.addWidget(self.sim_conf_tree_toolbar)
        self.verticalLayout_21.addWidget(self.sim_conf_tree_toolbar_frame)
        self.gridLayout.addWidget(self.sim_conf_tree_frame, 0, 0, 1, 1)
        self.log_frame = QtWidgets.QFrame(self.centralWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.log_frame.sizePolicy().hasHeightForWidth())
        self.log_frame.setSizePolicy(sizePolicy)
        self.log_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.log_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.log_frame.setObjectName("log_frame")
        self.verticalLayout_201 = QtWidgets.QVBoxLayout(self.log_frame)
        self.verticalLayout_201.setObjectName("verticalLayout_201")
        self.log_label = QtWidgets.QLabel(self.log_frame)
        self.log_label.setObjectName("log_label")
        self.verticalLayout_201.addWidget(self.log_label)
        self.log_box = QBetseePlainTextEdit(self.log_frame)
        self.log_box.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.log_box.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.log_box.setLineWidth(2)
        self.log_box.setDocumentTitle("")
        self.log_box.setUndoRedoEnabled(False)
        self.log_box.setLineWrapMode(QtWidgets.QPlainTextEdit.NoWrap)
        self.log_box.setReadOnly(True)
        self.log_box.setPlainText("")
        self.log_box.setTextInteractionFlags(QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.log_box.setBackgroundVisible(False)
        self.log_box.setObjectName("log_box")
        self.verticalLayout_201.addWidget(self.log_box)
        self.gridLayout.addWidget(self.log_frame, 1, 0, 1, 3)
        self.sim_conf_stack_area = QtWidgets.QScrollArea(self.centralWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(2)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.sim_conf_stack_area.sizePolicy().hasHeightForWidth())
        self.sim_conf_stack_area.setSizePolicy(sizePolicy)
        self.sim_conf_stack_area.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.sim_conf_stack_area.setWidgetResizable(True)
        self.sim_conf_stack_area.setObjectName("sim_conf_stack_area")
        self.sim_conf_stack = QBetseeSimConfStackedWidget()
        self.sim_conf_stack.setGeometry(QtCore.QRect(0, 0, 506, 836))
        font = QtGui.QFont()
        font.setPointSize(13)
        self.sim_conf_stack.setFont(font)
        self.sim_conf_stack.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.sim_conf_stack.setObjectName("sim_conf_stack")
        self.sim_conf_stack_page_Paths = QtWidgets.QWidget()
        self.sim_conf_stack_page_Paths.setObjectName("sim_conf_stack_page_Paths")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.sim_conf_stack_page_Paths)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.groupBox_50 = QtWidgets.QGroupBox(self.sim_conf_stack_page_Paths)
        self.groupBox_50.setToolTip("")
        self.groupBox_50.setProperty("is_page", True)
        self.groupBox_50.setObjectName("groupBox_50")
        self.verticalLayout_19 = QtWidgets.QVBoxLayout(self.groupBox_50)
        self.verticalLayout_19.setObjectName("verticalLayout_19")
        self.groupBox_13 = QtWidgets.QGroupBox(self.groupBox_50)
        self.groupBox_13.setObjectName("groupBox_13")
        self.formLayout_17 = QtWidgets.QFormLayout(self.groupBox_13)
        self.formLayout_17.setObjectName("formLayout_17")
        self.label_2 = QtWidgets.QLabel(self.groupBox_13)
        self.label_2.setObjectName("label_2")
        self.formLayout_17.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_2)
        self.sim_conf_path_seed_pick_file_line = QBetseeSimConfLineEdit(self.groupBox_13)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_conf_path_seed_pick_file_line.sizePolicy().hasHeightForWidth())
        self.sim_conf_path_seed_pick_file_line.setSizePolicy(sizePolicy)
        self.sim_conf_path_seed_pick_file_line.setText("")
        self.sim_conf_path_seed_pick_file_line.setObjectName("sim_conf_path_seed_pick_file_line")
        self.formLayout_17.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.sim_conf_path_seed_pick_file_line)
        self.verticalLayout_19.addWidget(self.groupBox_13)
        self.groupBox_11 = QtWidgets.QGroupBox(self.groupBox_50)
        self.groupBox_11.setObjectName("groupBox_11")
        self.formLayout_11 = QtWidgets.QFormLayout(self.groupBox_11)
        self.formLayout_11.setObjectName("formLayout_11")
        self.label = QtWidgets.QLabel(self.groupBox_11)
        self.label.setObjectName("label")
        self.formLayout_11.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label)
        self.widget_5 = QtWidgets.QWidget(self.groupBox_11)
        self.widget_5.setObjectName("widget_5")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.widget_5)
        self.horizontalLayout_5.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.sim_conf_path_init_pick_dir_line = QBetseeSimConfPathnameSubdirLineEdit(self.widget_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_conf_path_init_pick_dir_line.sizePolicy().hasHeightForWidth())
        self.sim_conf_path_init_pick_dir_line.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_path_init_pick_dir_line.setFont(font)
        self.sim_conf_path_init_pick_dir_line.setToolTip("")
        self.sim_conf_path_init_pick_dir_line.setText("")
        self.sim_conf_path_init_pick_dir_line.setObjectName("sim_conf_path_init_pick_dir_line")
        self.horizontalLayout_5.addWidget(self.sim_conf_path_init_pick_dir_line)
        self.sim_conf_path_init_pick_dir_btn = QtWidgets.QPushButton(self.widget_5)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_path_init_pick_dir_btn.setFont(font)
        self.sim_conf_path_init_pick_dir_btn.setObjectName("sim_conf_path_init_pick_dir_btn")
        self.horizontalLayout_5.addWidget(self.sim_conf_path_init_pick_dir_btn)
        self.formLayout_11.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.widget_5)
        self.label_4 = QtWidgets.QLabel(self.groupBox_11)
        self.label_4.setObjectName("label_4")
        self.formLayout_11.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_4)
        self.sim_conf_path_init_pick_file_line = QBetseeSimConfLineEdit(self.groupBox_11)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_conf_path_init_pick_file_line.sizePolicy().hasHeightForWidth())
        self.sim_conf_path_init_pick_file_line.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_path_init_pick_file_line.setFont(font)
        self.sim_conf_path_init_pick_file_line.setText("")
        self.sim_conf_path_init_pick_file_line.setObjectName("sim_conf_path_init_pick_file_line")
        self.formLayout_11.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.sim_conf_path_init_pick_file_line)
        self.label_3 = QtWidgets.QLabel(self.groupBox_11)
        self.label_3.setObjectName("label_3")
        self.formLayout_11.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_3)
        self.widget_6 = QtWidgets.QWidget(self.groupBox_11)
        self.widget_6.setObjectName("widget_6")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.widget_6)
        self.horizontalLayout_6.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.sim_conf_path_init_exp_dir_line = QBetseeSimConfPathnameSubdirLineEdit(self.widget_6)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_conf_path_init_exp_dir_line.sizePolicy().hasHeightForWidth())
        self.sim_conf_path_init_exp_dir_line.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_path_init_exp_dir_line.setFont(font)
        self.sim_conf_path_init_exp_dir_line.setToolTip("")
        self.sim_conf_path_init_exp_dir_line.setText("")
        self.sim_conf_path_init_exp_dir_line.setObjectName("sim_conf_path_init_exp_dir_line")
        self.horizontalLayout_6.addWidget(self.sim_conf_path_init_exp_dir_line)
        self.sim_conf_path_init_exp_dir_btn = QtWidgets.QPushButton(self.widget_6)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_path_init_exp_dir_btn.setFont(font)
        self.sim_conf_path_init_exp_dir_btn.setObjectName("sim_conf_path_init_exp_dir_btn")
        self.horizontalLayout_6.addWidget(self.sim_conf_path_init_exp_dir_btn)
        self.formLayout_11.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.widget_6)
        self.verticalLayout_19.addWidget(self.groupBox_11)
        self.groupBox_12 = QtWidgets.QGroupBox(self.groupBox_50)
        self.groupBox_12.setObjectName("groupBox_12")
        self.formLayout_16 = QtWidgets.QFormLayout(self.groupBox_12)
        self.formLayout_16.setObjectName("formLayout_16")
        self.label_5 = QtWidgets.QLabel(self.groupBox_12)
        self.label_5.setObjectName("label_5")
        self.formLayout_16.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_5)
        self.widget_7 = QtWidgets.QWidget(self.groupBox_12)
        self.widget_7.setObjectName("widget_7")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(self.widget_7)
        self.horizontalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.sim_conf_path_sim_pick_dir_line = QBetseeSimConfPathnameSubdirLineEdit(self.widget_7)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_conf_path_sim_pick_dir_line.sizePolicy().hasHeightForWidth())
        self.sim_conf_path_sim_pick_dir_line.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_path_sim_pick_dir_line.setFont(font)
        self.sim_conf_path_sim_pick_dir_line.setToolTip("")
        self.sim_conf_path_sim_pick_dir_line.setText("")
        self.sim_conf_path_sim_pick_dir_line.setObjectName("sim_conf_path_sim_pick_dir_line")
        self.horizontalLayout_7.addWidget(self.sim_conf_path_sim_pick_dir_line)
        self.sim_conf_path_sim_pick_dir_btn = QtWidgets.QPushButton(self.widget_7)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_path_sim_pick_dir_btn.setFont(font)
        self.sim_conf_path_sim_pick_dir_btn.setObjectName("sim_conf_path_sim_pick_dir_btn")
        self.horizontalLayout_7.addWidget(self.sim_conf_path_sim_pick_dir_btn)
        self.formLayout_16.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.widget_7)
        self.label_62 = QtWidgets.QLabel(self.groupBox_12)
        self.label_62.setObjectName("label_62")
        self.formLayout_16.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_62)
        self.sim_conf_path_sim_pick_file_line = QBetseeSimConfLineEdit(self.groupBox_12)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_conf_path_sim_pick_file_line.sizePolicy().hasHeightForWidth())
        self.sim_conf_path_sim_pick_file_line.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_path_sim_pick_file_line.setFont(font)
        self.sim_conf_path_sim_pick_file_line.setText("")
        self.sim_conf_path_sim_pick_file_line.setObjectName("sim_conf_path_sim_pick_file_line")
        self.formLayout_16.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.sim_conf_path_sim_pick_file_line)
        self.label_73 = QtWidgets.QLabel(self.groupBox_12)
        self.label_73.setObjectName("label_73")
        self.formLayout_16.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_73)
        self.widget_8 = QtWidgets.QWidget(self.groupBox_12)
        self.widget_8.setObjectName("widget_8")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(self.widget_8)
        self.horizontalLayout_8.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.sim_conf_path_sim_exp_dir_line = QBetseeSimConfPathnameSubdirLineEdit(self.widget_8)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_conf_path_sim_exp_dir_line.sizePolicy().hasHeightForWidth())
        self.sim_conf_path_sim_exp_dir_line.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_path_sim_exp_dir_line.setFont(font)
        self.sim_conf_path_sim_exp_dir_line.setToolTip("")
        self.sim_conf_path_sim_exp_dir_line.setText("")
        self.sim_conf_path_sim_exp_dir_line.setObjectName("sim_conf_path_sim_exp_dir_line")
        self.horizontalLayout_8.addWidget(self.sim_conf_path_sim_exp_dir_line)
        self.sim_conf_path_sim_exp_dir_btn = QtWidgets.QPushButton(self.widget_8)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_path_sim_exp_dir_btn.setFont(font)
        self.sim_conf_path_sim_exp_dir_btn.setObjectName("sim_conf_path_sim_exp_dir_btn")
        self.horizontalLayout_8.addWidget(self.sim_conf_path_sim_exp_dir_btn)
        self.formLayout_16.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.widget_8)
        self.verticalLayout_19.addWidget(self.groupBox_12)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_19.addItem(spacerItem)
        self.gridLayout_2.addWidget(self.groupBox_50, 0, 0, 1, 1)
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_Paths)
        self.sim_conf_stack_page_Time = QtWidgets.QWidget()
        self.sim_conf_stack_page_Time.setObjectName("sim_conf_stack_page_Time")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.sim_conf_stack_page_Time)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.groupBox_51 = QtWidgets.QGroupBox(self.sim_conf_stack_page_Time)
        self.groupBox_51.setToolTip("")
        self.groupBox_51.setProperty("is_page", True)
        self.groupBox_51.setObjectName("groupBox_51")
        self.verticalLayout_22 = QtWidgets.QVBoxLayout(self.groupBox_51)
        self.verticalLayout_22.setObjectName("verticalLayout_22")
        self.groupBox_14 = QtWidgets.QGroupBox(self.groupBox_51)
        self.groupBox_14.setObjectName("groupBox_14")
        self.formLayout = QtWidgets.QFormLayout(self.groupBox_14)
        self.formLayout.setObjectName("formLayout")
        self.label_77 = QtWidgets.QLabel(self.groupBox_14)
        self.label_77.setObjectName("label_77")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_77)
        self.widget_9 = QtWidgets.QWidget(self.groupBox_14)
        self.widget_9.setObjectName("widget_9")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout(self.widget_9)
        self.horizontalLayout_9.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.sim_conf_time_init_total = QBetseeSimConfDoubleSpinBox(self.widget_9)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_time_init_total.setFont(font)
        self.sim_conf_time_init_total.setToolTip("")
        self.sim_conf_time_init_total.setSuffix("")
        self.sim_conf_time_init_total.setDecimals(3)
        self.sim_conf_time_init_total.setSingleStep(0.1)
        self.sim_conf_time_init_total.setObjectName("sim_conf_time_init_total")
        self.horizontalLayout_9.addWidget(self.sim_conf_time_init_total)
        self.label_6 = QtWidgets.QLabel(self.widget_9)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_6.setFont(font)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_9.addWidget(self.label_6)
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.widget_9)
        self.label_75 = QtWidgets.QLabel(self.groupBox_14)
        self.label_75.setObjectName("label_75")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_75)
        self.widget_10 = QtWidgets.QWidget(self.groupBox_14)
        self.widget_10.setObjectName("widget_10")
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout(self.widget_10)
        self.horizontalLayout_10.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.sim_conf_time_init_step = QBetseeSimConfDoubleSpinBox(self.widget_10)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_time_init_step.setFont(font)
        self.sim_conf_time_init_step.setToolTip("")
        self.sim_conf_time_init_step.setSuffix("")
        self.sim_conf_time_init_step.setDecimals(3)
        self.sim_conf_time_init_step.setSingleStep(0.1)
        self.sim_conf_time_init_step.setObjectName("sim_conf_time_init_step")
        self.horizontalLayout_10.addWidget(self.sim_conf_time_init_step)
        self.label_7 = QtWidgets.QLabel(self.widget_10)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_7.setFont(font)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_10.addWidget(self.label_7)
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.widget_10)
        self.label_76 = QtWidgets.QLabel(self.groupBox_14)
        self.label_76.setObjectName("label_76")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_76)
        self.widget_11 = QtWidgets.QWidget(self.groupBox_14)
        self.widget_11.setObjectName("widget_11")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout(self.widget_11)
        self.horizontalLayout_11.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.sim_conf_time_init_sampling = QBetseeSimConfDoubleSpinBox(self.widget_11)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_time_init_sampling.setFont(font)
        self.sim_conf_time_init_sampling.setToolTip("")
        self.sim_conf_time_init_sampling.setSuffix("")
        self.sim_conf_time_init_sampling.setDecimals(3)
        self.sim_conf_time_init_sampling.setSingleStep(0.1)
        self.sim_conf_time_init_sampling.setObjectName("sim_conf_time_init_sampling")
        self.horizontalLayout_11.addWidget(self.sim_conf_time_init_sampling)
        self.label_8 = QtWidgets.QLabel(self.widget_11)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_8.setFont(font)
        self.label_8.setObjectName("label_8")
        self.horizontalLayout_11.addWidget(self.label_8)
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.widget_11)
        self.verticalLayout_22.addWidget(self.groupBox_14)
        self.groupBox_15 = QtWidgets.QGroupBox(self.groupBox_51)
        self.groupBox_15.setObjectName("groupBox_15")
        self.formLayout_18 = QtWidgets.QFormLayout(self.groupBox_15)
        self.formLayout_18.setObjectName("formLayout_18")
        self.label_78 = QtWidgets.QLabel(self.groupBox_15)
        self.label_78.setObjectName("label_78")
        self.formLayout_18.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_78)
        self.widget_12 = QtWidgets.QWidget(self.groupBox_15)
        self.widget_12.setObjectName("widget_12")
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout(self.widget_12)
        self.horizontalLayout_12.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.sim_conf_time_sim_total = QBetseeSimConfDoubleSpinBox(self.widget_12)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_time_sim_total.setFont(font)
        self.sim_conf_time_sim_total.setToolTip("")
        self.sim_conf_time_sim_total.setSuffix("")
        self.sim_conf_time_sim_total.setDecimals(3)
        self.sim_conf_time_sim_total.setSingleStep(0.1)
        self.sim_conf_time_sim_total.setObjectName("sim_conf_time_sim_total")
        self.horizontalLayout_12.addWidget(self.sim_conf_time_sim_total)
        self.label_9 = QtWidgets.QLabel(self.widget_12)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_9.setFont(font)
        self.label_9.setObjectName("label_9")
        self.horizontalLayout_12.addWidget(self.label_9)
        self.formLayout_18.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.widget_12)
        self.label_79 = QtWidgets.QLabel(self.groupBox_15)
        self.label_79.setObjectName("label_79")
        self.formLayout_18.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_79)
        self.widget_13 = QtWidgets.QWidget(self.groupBox_15)
        self.widget_13.setObjectName("widget_13")
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout(self.widget_13)
        self.horizontalLayout_13.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.sim_conf_time_sim_step = QBetseeSimConfDoubleSpinBox(self.widget_13)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_time_sim_step.setFont(font)
        self.sim_conf_time_sim_step.setToolTip("")
        self.sim_conf_time_sim_step.setSuffix("")
        self.sim_conf_time_sim_step.setDecimals(3)
        self.sim_conf_time_sim_step.setSingleStep(0.1)
        self.sim_conf_time_sim_step.setObjectName("sim_conf_time_sim_step")
        self.horizontalLayout_13.addWidget(self.sim_conf_time_sim_step)
        self.label_10 = QtWidgets.QLabel(self.widget_13)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_10.setFont(font)
        self.label_10.setObjectName("label_10")
        self.horizontalLayout_13.addWidget(self.label_10)
        self.formLayout_18.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.widget_13)
        self.label_80 = QtWidgets.QLabel(self.groupBox_15)
        self.label_80.setObjectName("label_80")
        self.formLayout_18.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_80)
        self.widget_14 = QtWidgets.QWidget(self.groupBox_15)
        self.widget_14.setObjectName("widget_14")
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout(self.widget_14)
        self.horizontalLayout_14.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.sim_conf_time_sim_sampling = QBetseeSimConfDoubleSpinBox(self.widget_14)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_time_sim_sampling.setFont(font)
        self.sim_conf_time_sim_sampling.setToolTip("")
        self.sim_conf_time_sim_sampling.setSuffix("")
        self.sim_conf_time_sim_sampling.setDecimals(3)
        self.sim_conf_time_sim_sampling.setSingleStep(0.1)
        self.sim_conf_time_sim_sampling.setObjectName("sim_conf_time_sim_sampling")
        self.horizontalLayout_14.addWidget(self.sim_conf_time_sim_sampling)
        self.label_11 = QtWidgets.QLabel(self.widget_14)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_11.setFont(font)
        self.label_11.setObjectName("label_11")
        self.horizontalLayout_14.addWidget(self.label_11)
        self.formLayout_18.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.widget_14)
        self.verticalLayout_22.addWidget(self.groupBox_15)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_22.addItem(spacerItem1)
        self.gridLayout_3.addWidget(self.groupBox_51, 0, 0, 1, 1)
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_Time)
        self.sim_conf_stack_page_Ions = QtWidgets.QWidget()
        self.sim_conf_stack_page_Ions.setObjectName("sim_conf_stack_page_Ions")
        self.gridLayout_21 = QtWidgets.QGridLayout(self.sim_conf_stack_page_Ions)
        self.gridLayout_21.setObjectName("gridLayout_21")
        self.groupBox_52 = QtWidgets.QGroupBox(self.sim_conf_stack_page_Ions)
        self.groupBox_52.setToolTip("")
        self.groupBox_52.setProperty("is_page", True)
        self.groupBox_52.setObjectName("groupBox_52")
        self.verticalLayout_24 = QtWidgets.QVBoxLayout(self.groupBox_52)
        self.verticalLayout_24.setObjectName("verticalLayout_24")
        self.groupBox_20 = QtWidgets.QGroupBox(self.groupBox_52)
        self.groupBox_20.setObjectName("groupBox_20")
        self.formLayout_2 = QtWidgets.QFormLayout(self.groupBox_20)
        self.formLayout_2.setObjectName("formLayout_2")
        self.label_14 = QtWidgets.QLabel(self.groupBox_20)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_14.setFont(font)
        self.label_14.setObjectName("label_14")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_14)
        self.sim_conf_ion_profile = QBetseeSimConfEnumComboBox(self.groupBox_20)
        self.sim_conf_ion_profile.setObjectName("sim_conf_ion_profile")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.sim_conf_ion_profile)
        self.widget_24 = QtWidgets.QWidget(self.groupBox_20)
        self.widget_24.setObjectName("widget_24")
        self.horizontalLayout_24 = QtWidgets.QHBoxLayout(self.widget_24)
        self.horizontalLayout_24.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_24.setObjectName("horizontalLayout_24")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.widget_24)
        self.verticalLayout_24.addWidget(self.groupBox_20)
        self.sim_conf_ion_custom = QtWidgets.QGroupBox(self.groupBox_52)
        self.sim_conf_ion_custom.setObjectName("sim_conf_ion_custom")
        self.verticalLayout_23 = QtWidgets.QVBoxLayout(self.sim_conf_ion_custom)
        self.verticalLayout_23.setObjectName("verticalLayout_23")
        self.groupBox_18 = QtWidgets.QGroupBox(self.sim_conf_ion_custom)
        self.groupBox_18.setObjectName("groupBox_18")
        self.formLayout_19 = QtWidgets.QFormLayout(self.groupBox_18)
        self.formLayout_19.setObjectName("formLayout_19")
        self.label_84 = QtWidgets.QLabel(self.groupBox_18)
        self.label_84.setObjectName("label_84")
        self.formLayout_19.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_84)
        self.widget_18 = QtWidgets.QWidget(self.groupBox_18)
        self.widget_18.setObjectName("widget_18")
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout(self.widget_18)
        self.horizontalLayout_18.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.sim_conf_time_sim_total_2 = QtWidgets.QDoubleSpinBox(self.widget_18)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.sim_conf_time_sim_total_2.setFont(font)
        self.sim_conf_time_sim_total_2.setToolTip("")
        self.sim_conf_time_sim_total_2.setSuffix("")
        self.sim_conf_time_sim_total_2.setDecimals(3)
        self.sim_conf_time_sim_total_2.setSingleStep(0.1)
        self.sim_conf_time_sim_total_2.setObjectName("sim_conf_time_sim_total_2")
        self.horizontalLayout_18.addWidget(self.sim_conf_time_sim_total_2)
        self.label_85 = QtWidgets.QLabel(self.widget_18)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.label_85.setFont(font)
        self.label_85.setObjectName("label_85")
        self.horizontalLayout_18.addWidget(self.label_85)
        self.formLayout_19.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.widget_18)
        self.label_86 = QtWidgets.QLabel(self.groupBox_18)
        self.label_86.setObjectName("label_86")
        self.formLayout_19.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_86)
        self.widget_19 = QtWidgets.QWidget(self.groupBox_18)
        self.widget_19.setObjectName("widget_19")
        self.horizontalLayout_19 = QtWidgets.QHBoxLayout(self.widget_19)
        self.horizontalLayout_19.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_19.setObjectName("horizontalLayout_19")
        self.sim_conf_time_sim_step_2 = QtWidgets.QDoubleSpinBox(self.widget_19)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.sim_conf_time_sim_step_2.setFont(font)
        self.sim_conf_time_sim_step_2.setToolTip("")
        self.sim_conf_time_sim_step_2.setSuffix("")
        self.sim_conf_time_sim_step_2.setDecimals(3)
        self.sim_conf_time_sim_step_2.setSingleStep(0.1)
        self.sim_conf_time_sim_step_2.setObjectName("sim_conf_time_sim_step_2")
        self.horizontalLayout_19.addWidget(self.sim_conf_time_sim_step_2)
        self.label_87 = QtWidgets.QLabel(self.widget_19)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.label_87.setFont(font)
        self.label_87.setObjectName("label_87")
        self.horizontalLayout_19.addWidget(self.label_87)
        self.formLayout_19.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.widget_19)
        self.label_88 = QtWidgets.QLabel(self.groupBox_18)
        self.label_88.setObjectName("label_88")
        self.formLayout_19.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_88)
        self.widget_20 = QtWidgets.QWidget(self.groupBox_18)
        self.widget_20.setObjectName("widget_20")
        self.horizontalLayout_20 = QtWidgets.QHBoxLayout(self.widget_20)
        self.horizontalLayout_20.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_20.setObjectName("horizontalLayout_20")
        self.sim_conf_time_sim_sampling_2 = QtWidgets.QDoubleSpinBox(self.widget_20)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.sim_conf_time_sim_sampling_2.setFont(font)
        self.sim_conf_time_sim_sampling_2.setToolTip("")
        self.sim_conf_time_sim_sampling_2.setSuffix("")
        self.sim_conf_time_sim_sampling_2.setDecimals(3)
        self.sim_conf_time_sim_sampling_2.setSingleStep(0.1)
        self.sim_conf_time_sim_sampling_2.setObjectName("sim_conf_time_sim_sampling_2")
        self.horizontalLayout_20.addWidget(self.sim_conf_time_sim_sampling_2)
        self.label_89 = QtWidgets.QLabel(self.widget_20)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.label_89.setFont(font)
        self.label_89.setObjectName("label_89")
        self.horizontalLayout_20.addWidget(self.label_89)
        self.formLayout_19.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.widget_20)
        self.verticalLayout_23.addWidget(self.groupBox_18)
        self.widget_21 = QtWidgets.QWidget(self.sim_conf_ion_custom)
        self.widget_21.setObjectName("widget_21")
        self.horizontalLayout_21 = QtWidgets.QHBoxLayout(self.widget_21)
        self.horizontalLayout_21.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_21.setObjectName("horizontalLayout_21")
        self.verticalLayout_23.addWidget(self.widget_21)
        self.widget_22 = QtWidgets.QWidget(self.sim_conf_ion_custom)
        self.widget_22.setObjectName("widget_22")
        self.horizontalLayout_22 = QtWidgets.QHBoxLayout(self.widget_22)
        self.horizontalLayout_22.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_22.setObjectName("horizontalLayout_22")
        self.verticalLayout_23.addWidget(self.widget_22)
        self.widget_23 = QtWidgets.QWidget(self.sim_conf_ion_custom)
        self.widget_23.setObjectName("widget_23")
        self.horizontalLayout_23 = QtWidgets.QHBoxLayout(self.widget_23)
        self.horizontalLayout_23.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_23.setObjectName("horizontalLayout_23")
        self.verticalLayout_23.addWidget(self.widget_23)
        self.verticalLayout_24.addWidget(self.sim_conf_ion_custom)
        self.gridLayout_21.addWidget(self.groupBox_52, 0, 0, 1, 1)
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_Ions)
        self.sim_conf_stack_page_Space = QtWidgets.QWidget()
        self.sim_conf_stack_page_Space.setToolTip("")
        self.sim_conf_stack_page_Space.setObjectName("sim_conf_stack_page_Space")
        self.gridLayout_50 = QtWidgets.QGridLayout(self.sim_conf_stack_page_Space)
        self.gridLayout_50.setObjectName("gridLayout_50")
        self.groupBox_53 = QtWidgets.QGroupBox(self.sim_conf_stack_page_Space)
        self.groupBox_53.setToolTip("")
        self.groupBox_53.setProperty("is_page", True)
        self.groupBox_53.setObjectName("groupBox_53")
        self.verticalLayout_17 = QtWidgets.QVBoxLayout(self.groupBox_53)
        self.verticalLayout_17.setObjectName("verticalLayout_17")
        self.groupBox_17 = QtWidgets.QGroupBox(self.groupBox_53)
        self.groupBox_17.setObjectName("groupBox_17")
        self.formLayout_8 = QtWidgets.QFormLayout(self.groupBox_17)
        self.formLayout_8.setObjectName("formLayout_8")
        self.label_18 = QtWidgets.QLabel(self.groupBox_17)
        self.label_18.setObjectName("label_18")
        self.formLayout_8.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_18)
        self.widget_17 = QtWidgets.QWidget(self.groupBox_17)
        self.widget_17.setObjectName("widget_17")
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout(self.widget_17)
        self.horizontalLayout_17.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        self.sim_conf_space_intra_cell_radius = QBetseeSimConfDoubleSpinBox(self.widget_17)
        self.sim_conf_space_intra_cell_radius.setToolTip("")
        self.sim_conf_space_intra_cell_radius.setObjectName("sim_conf_space_intra_cell_radius")
        self.horizontalLayout_17.addWidget(self.sim_conf_space_intra_cell_radius)
        self.label_83 = QtWidgets.QLabel(self.widget_17)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_83.setFont(font)
        self.label_83.setObjectName("label_83")
        self.horizontalLayout_17.addWidget(self.label_83)
        self.formLayout_8.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.widget_17)
        self.label_81 = QtWidgets.QLabel(self.groupBox_17)
        self.label_81.setObjectName("label_81")
        self.formLayout_8.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_81)
        self.label_20 = QtWidgets.QLabel(self.groupBox_17)
        self.label_20.setObjectName("label_20")
        self.formLayout_8.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.label_20)
        self.widget_25 = QtWidgets.QWidget(self.groupBox_17)
        self.widget_25.setObjectName("widget_25")
        self.horizontalLayout_25 = QtWidgets.QHBoxLayout(self.widget_25)
        self.horizontalLayout_25.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_25.setObjectName("horizontalLayout_25")
        self.sim_conf_space_intra_lattice_disorder = QBetseeSimConfDoubleSpinBox(self.widget_25)
        self.sim_conf_space_intra_lattice_disorder.setToolTip("")
        self.sim_conf_space_intra_lattice_disorder.setDecimals(1)
        self.sim_conf_space_intra_lattice_disorder.setMaximum(1.0)
        self.sim_conf_space_intra_lattice_disorder.setObjectName("sim_conf_space_intra_lattice_disorder")
        self.horizontalLayout_25.addWidget(self.sim_conf_space_intra_lattice_disorder)
        self.label_90 = QtWidgets.QLabel(self.widget_25)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_90.setFont(font)
        self.label_90.setObjectName("label_90")
        self.horizontalLayout_25.addWidget(self.label_90)
        self.formLayout_8.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.widget_25)
        self.widget_3 = QtWidgets.QWidget(self.groupBox_17)
        self.widget_3.setObjectName("widget_3")
        self.verticalLayout_25 = QtWidgets.QVBoxLayout(self.widget_3)
        self.verticalLayout_25.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_25.setObjectName("verticalLayout_25")
        self.sim_conf_space_intra_lattice_hex = QtWidgets.QRadioButton(self.widget_3)
        self.sim_conf_space_intra_lattice_hex.setObjectName("sim_conf_space_intra_lattice_hex")
        self.sim_conf_space_intra_lattice_type = QBetseeSimConfEnumRadioButtonGroup(main_window)
        self.sim_conf_space_intra_lattice_type.setObjectName("sim_conf_space_intra_lattice_type")
        self.sim_conf_space_intra_lattice_type.addButton(self.sim_conf_space_intra_lattice_hex)
        self.verticalLayout_25.addWidget(self.sim_conf_space_intra_lattice_hex)
        self.sim_conf_space_intra_lattice_square = QtWidgets.QRadioButton(self.widget_3)
        self.sim_conf_space_intra_lattice_square.setObjectName("sim_conf_space_intra_lattice_square")
        self.sim_conf_space_intra_lattice_type.addButton(self.sim_conf_space_intra_lattice_square)
        self.verticalLayout_25.addWidget(self.sim_conf_space_intra_lattice_square)
        self.formLayout_8.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.widget_3)
        self.verticalLayout_17.addWidget(self.groupBox_17)
        self.groupBox_16 = QtWidgets.QGroupBox(self.groupBox_53)
        self.groupBox_16.setObjectName("groupBox_16")
        self.formLayout_5 = QtWidgets.QFormLayout(self.groupBox_16)
        self.formLayout_5.setObjectName("formLayout_5")
        self.label_17 = QtWidgets.QLabel(self.groupBox_16)
        self.label_17.setObjectName("label_17")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_17)
        self.widget_15 = QtWidgets.QWidget(self.groupBox_16)
        self.widget_15.setObjectName("widget_15")
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout(self.widget_15)
        self.horizontalLayout_15.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.sim_conf_space_extra_world_len = QBetseeSimConfDoubleSpinBox(self.widget_15)
        self.sim_conf_space_extra_world_len.setToolTip("")
        self.sim_conf_space_extra_world_len.setObjectName("sim_conf_space_extra_world_len")
        self.horizontalLayout_15.addWidget(self.sim_conf_space_extra_world_len)
        self.label_19 = QtWidgets.QLabel(self.widget_15)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_19.setFont(font)
        self.label_19.setObjectName("label_19")
        self.horizontalLayout_15.addWidget(self.label_19)
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.widget_15)
        self.label_74 = QtWidgets.QLabel(self.groupBox_16)
        self.label_74.setObjectName("label_74")
        self.formLayout_5.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_74)
        self.widget_16 = QtWidgets.QWidget(self.groupBox_16)
        self.widget_16.setObjectName("widget_16")
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout(self.widget_16)
        self.horizontalLayout_16.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        self.sim_conf_space_extra_grid_size = QBetseeSimConfIntSpinBox(self.widget_16)
        self.sim_conf_space_extra_grid_size.setToolTip("")
        self.sim_conf_space_extra_grid_size.setMaximum(999)
        self.sim_conf_space_extra_grid_size.setObjectName("sim_conf_space_extra_grid_size")
        self.horizontalLayout_16.addWidget(self.sim_conf_space_extra_grid_size)
        self.label_82 = QtWidgets.QLabel(self.widget_16)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_82.setFont(font)
        self.label_82.setObjectName("label_82")
        self.horizontalLayout_16.addWidget(self.label_82)
        self.formLayout_5.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.widget_16)
        self.label_12 = QtWidgets.QLabel(self.groupBox_16)
        self.label_12.setObjectName("label_12")
        self.formLayout_5.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_12)
        self.sim_conf_space_extra_is_ecm = QBetseeSimConfCheckBox(self.groupBox_16)
        self.sim_conf_space_extra_is_ecm.setText("")
        self.sim_conf_space_extra_is_ecm.setObjectName("sim_conf_space_extra_is_ecm")
        self.formLayout_5.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.sim_conf_space_extra_is_ecm)
        self.verticalLayout_17.addWidget(self.groupBox_16)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_17.addItem(spacerItem2)
        self.gridLayout_50.addWidget(self.groupBox_53, 0, 0, 1, 1)
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_Space)
        self.sim_conf_stack_page_Space_Tissue = QtWidgets.QWidget()
        self.sim_conf_stack_page_Space_Tissue.setObjectName("sim_conf_stack_page_Space_Tissue")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.sim_conf_stack_page_Space_Tissue)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.groupBox_23 = QtWidgets.QGroupBox(self.sim_conf_stack_page_Space_Tissue)
        self.groupBox_23.setProperty("is_page", True)
        self.groupBox_23.setObjectName("groupBox_23")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.groupBox_23)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.groupBox_22 = QtWidgets.QGroupBox(self.groupBox_23)
        self.groupBox_22.setObjectName("groupBox_22")
        self.formLayout_10 = QtWidgets.QFormLayout(self.groupBox_22)
        self.formLayout_10.setObjectName("formLayout_10")
        self.label_16 = QtWidgets.QLabel(self.groupBox_22)
        self.label_16.setObjectName("label_16")
        self.formLayout_10.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_16)
        self.sim_conf_tis_default_name = QBetseeSimConfLineEdit(self.groupBox_22)
        self.sim_conf_tis_default_name.setObjectName("sim_conf_tis_default_name")
        self.formLayout_10.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.sim_conf_tis_default_name)
        self.verticalLayout_6.addWidget(self.groupBox_22)
        self.groupBox_21 = QtWidgets.QGroupBox(self.groupBox_23)
        self.groupBox_21.setObjectName("groupBox_21")
        self.formLayout_20 = QtWidgets.QFormLayout(self.groupBox_21)
        self.formLayout_20.setObjectName("formLayout_20")
        self.label_91 = QtWidgets.QLabel(self.groupBox_21)
        self.label_91.setObjectName("label_91")
        self.formLayout_20.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_91)
        self.widget_26 = QtWidgets.QWidget(self.groupBox_21)
        self.widget_26.setObjectName("widget_26")
        self.horizontalLayout_26 = QtWidgets.QHBoxLayout(self.widget_26)
        self.horizontalLayout_26.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_26.setObjectName("horizontalLayout_26")
        self.sim_conf_tis_default_image_line = QBetseeSimConfPathnameImageLineEdit(self.widget_26)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_conf_tis_default_image_line.sizePolicy().hasHeightForWidth())
        self.sim_conf_tis_default_image_line.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_tis_default_image_line.setFont(font)
        self.sim_conf_tis_default_image_line.setToolTip("")
        self.sim_conf_tis_default_image_line.setText("")
        self.sim_conf_tis_default_image_line.setObjectName("sim_conf_tis_default_image_line")
        self.horizontalLayout_26.addWidget(self.sim_conf_tis_default_image_line)
        self.sim_conf_tis_default_image_btn = QtWidgets.QPushButton(self.widget_26)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_tis_default_image_btn.setFont(font)
        self.sim_conf_tis_default_image_btn.setObjectName("sim_conf_tis_default_image_btn")
        self.horizontalLayout_26.addWidget(self.sim_conf_tis_default_image_btn)
        self.formLayout_20.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.widget_26)
        self.sim_conf_tis_default_image_label = QBetseeLabelImage(self.groupBox_21)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_conf_tis_default_image_label.setFont(font)
        self.sim_conf_tis_default_image_label.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.sim_conf_tis_default_image_label.setObjectName("sim_conf_tis_default_image_label")
        self.formLayout_20.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.sim_conf_tis_default_image_label)
        self.verticalLayout_6.addWidget(self.groupBox_21)
        self.groupBox_24 = QtWidgets.QGroupBox(self.groupBox_23)
        self.groupBox_24.setObjectName("groupBox_24")
        self.formLayout_9 = QtWidgets.QFormLayout(self.groupBox_24)
        self.formLayout_9.setObjectName("formLayout_9")
        self.label_54 = QtWidgets.QLabel(self.groupBox_24)
        self.label_54.setObjectName("label_54")
        self.formLayout_9.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_54)
        self.widget_27 = QtWidgets.QWidget(self.groupBox_24)
        self.widget_27.setObjectName("widget_27")
        self.horizontalLayout_27 = QtWidgets.QHBoxLayout(self.widget_27)
        self.horizontalLayout_27.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_27.setObjectName("horizontalLayout_27")
        self.sim_conf_tis_default_mem_Na = QBetseeSimConfDoubleSpinBox(self.widget_27)
        self.sim_conf_tis_default_mem_Na.setToolTip("")
        self.sim_conf_tis_default_mem_Na.setObjectName("sim_conf_tis_default_mem_Na")
        self.horizontalLayout_27.addWidget(self.sim_conf_tis_default_mem_Na)
        self.label_92 = QtWidgets.QLabel(self.widget_27)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_92.setFont(font)
        self.label_92.setToolTip("")
        self.label_92.setObjectName("label_92")
        self.horizontalLayout_27.addWidget(self.label_92)
        self.formLayout_9.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.widget_27)
        self.label_55 = QtWidgets.QLabel(self.groupBox_24)
        self.label_55.setObjectName("label_55")
        self.formLayout_9.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_55)
        self.widget_28 = QtWidgets.QWidget(self.groupBox_24)
        self.widget_28.setObjectName("widget_28")
        self.horizontalLayout_28 = QtWidgets.QHBoxLayout(self.widget_28)
        self.horizontalLayout_28.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_28.setObjectName("horizontalLayout_28")
        self.sim_conf_tis_default_mem_K = QBetseeSimConfDoubleSpinBox(self.widget_28)
        self.sim_conf_tis_default_mem_K.setToolTip("")
        self.sim_conf_tis_default_mem_K.setObjectName("sim_conf_tis_default_mem_K")
        self.horizontalLayout_28.addWidget(self.sim_conf_tis_default_mem_K)
        self.label_93 = QtWidgets.QLabel(self.widget_28)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_93.setFont(font)
        self.label_93.setToolTip("")
        self.label_93.setObjectName("label_93")
        self.horizontalLayout_28.addWidget(self.label_93)
        self.formLayout_9.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.widget_28)
        self.label_56 = QtWidgets.QLabel(self.groupBox_24)
        self.label_56.setObjectName("label_56")
        self.formLayout_9.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_56)
        self.widget_29 = QtWidgets.QWidget(self.groupBox_24)
        self.widget_29.setObjectName("widget_29")
        self.horizontalLayout_29 = QtWidgets.QHBoxLayout(self.widget_29)
        self.horizontalLayout_29.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_29.setObjectName("horizontalLayout_29")
        self.sim_conf_tis_default_mem_Cl = QBetseeSimConfDoubleSpinBox(self.widget_29)
        self.sim_conf_tis_default_mem_Cl.setToolTip("")
        self.sim_conf_tis_default_mem_Cl.setObjectName("sim_conf_tis_default_mem_Cl")
        self.horizontalLayout_29.addWidget(self.sim_conf_tis_default_mem_Cl)
        self.label_94 = QtWidgets.QLabel(self.widget_29)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_94.setFont(font)
        self.label_94.setToolTip("")
        self.label_94.setObjectName("label_94")
        self.horizontalLayout_29.addWidget(self.label_94)
        self.formLayout_9.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.widget_29)
        self.label_57 = QtWidgets.QLabel(self.groupBox_24)
        self.label_57.setObjectName("label_57")
        self.formLayout_9.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_57)
        self.widget_30 = QtWidgets.QWidget(self.groupBox_24)
        self.widget_30.setObjectName("widget_30")
        self.horizontalLayout_30 = QtWidgets.QHBoxLayout(self.widget_30)
        self.horizontalLayout_30.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_30.setObjectName("horizontalLayout_30")
        self.sim_conf_tis_default_mem_Ca = QBetseeSimConfDoubleSpinBox(self.widget_30)
        self.sim_conf_tis_default_mem_Ca.setToolTip("")
        self.sim_conf_tis_default_mem_Ca.setObjectName("sim_conf_tis_default_mem_Ca")
        self.horizontalLayout_30.addWidget(self.sim_conf_tis_default_mem_Ca)
        self.label_95 = QtWidgets.QLabel(self.widget_30)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_95.setFont(font)
        self.label_95.setToolTip("")
        self.label_95.setObjectName("label_95")
        self.horizontalLayout_30.addWidget(self.label_95)
        self.formLayout_9.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.widget_30)
        self.label_59 = QtWidgets.QLabel(self.groupBox_24)
        self.label_59.setObjectName("label_59")
        self.formLayout_9.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.label_59)
        self.widget_32 = QtWidgets.QWidget(self.groupBox_24)
        self.widget_32.setObjectName("widget_32")
        self.horizontalLayout_32 = QtWidgets.QHBoxLayout(self.widget_32)
        self.horizontalLayout_32.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_32.setObjectName("horizontalLayout_32")
        self.sim_conf_tis_default_mem_M = QBetseeSimConfDoubleSpinBox(self.widget_32)
        self.sim_conf_tis_default_mem_M.setToolTip("")
        self.sim_conf_tis_default_mem_M.setObjectName("sim_conf_tis_default_mem_M")
        self.horizontalLayout_32.addWidget(self.sim_conf_tis_default_mem_M)
        self.label_97 = QtWidgets.QLabel(self.widget_32)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_97.setFont(font)
        self.label_97.setToolTip("")
        self.label_97.setObjectName("label_97")
        self.horizontalLayout_32.addWidget(self.label_97)
        self.formLayout_9.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.widget_32)
        self.label_60 = QtWidgets.QLabel(self.groupBox_24)
        self.label_60.setObjectName("label_60")
        self.formLayout_9.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.label_60)
        self.widget_33 = QtWidgets.QWidget(self.groupBox_24)
        self.widget_33.setObjectName("widget_33")
        self.horizontalLayout_33 = QtWidgets.QHBoxLayout(self.widget_33)
        self.horizontalLayout_33.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_33.setObjectName("horizontalLayout_33")
        self.sim_conf_tis_default_mem_P = QBetseeSimConfDoubleSpinBox(self.widget_33)
        self.sim_conf_tis_default_mem_P.setToolTip("")
        self.sim_conf_tis_default_mem_P.setObjectName("sim_conf_tis_default_mem_P")
        self.horizontalLayout_33.addWidget(self.sim_conf_tis_default_mem_P)
        self.label_98 = QtWidgets.QLabel(self.widget_33)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_98.setFont(font)
        self.label_98.setToolTip("")
        self.label_98.setObjectName("label_98")
        self.horizontalLayout_33.addWidget(self.label_98)
        self.formLayout_9.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.widget_33)
        self.verticalLayout_6.addWidget(self.groupBox_24)
        spacerItem3 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_6.addItem(spacerItem3)
        self.verticalLayout_7.addWidget(self.groupBox_23)
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_Space_Tissue)
        self.sim_conf_stack_page_DynamicChannels = QtWidgets.QWidget()
        self.sim_conf_stack_page_DynamicChannels.setObjectName("sim_conf_stack_page_DynamicChannels")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.sim_conf_stack_page_DynamicChannels)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.groupBox_DynamicChannels = QtWidgets.QGroupBox(self.sim_conf_stack_page_DynamicChannels)
        self.groupBox_DynamicChannels.setObjectName("groupBox_DynamicChannels")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.groupBox_DynamicChannels)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        spacerItem4 = QtWidgets.QSpacerItem(20, 16, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_10.addItem(spacerItem4)
        self.frame_dynChannel_0 = QtWidgets.QFrame(self.groupBox_DynamicChannels)
        self.frame_dynChannel_0.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_dynChannel_0.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.frame_dynChannel_0.setLineWidth(4)
        self.frame_dynChannel_0.setObjectName("frame_dynChannel_0")
        self.formLayout_4 = QtWidgets.QFormLayout(self.frame_dynChannel_0)
        self.formLayout_4.setObjectName("formLayout_4")
        self.radioButton = QtWidgets.QRadioButton(self.frame_dynChannel_0)
        self.radioButton.setObjectName("radioButton")
        self.formLayout_4.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.radioButton)
        spacerItem5 = QtWidgets.QSpacerItem(20, 16, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.formLayout_4.setItem(1, QtWidgets.QFormLayout.LabelRole, spacerItem5)
        self.label_15 = QtWidgets.QLabel(self.frame_dynChannel_0)
        self.label_15.setObjectName("label_15")
        self.formLayout_4.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_15)
        self.comboBox_chanClass = QtWidgets.QComboBox(self.frame_dynChannel_0)
        self.comboBox_chanClass.setObjectName("comboBox_chanClass")
        self.formLayout_4.setWidget(3, QtWidgets.QFormLayout.SpanningRole, self.comboBox_chanClass)
        self.label_41 = QtWidgets.QLabel(self.frame_dynChannel_0)
        self.label_41.setObjectName("label_41")
        self.formLayout_4.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.label_41)
        self.comboBox_chanType = QtWidgets.QComboBox(self.frame_dynChannel_0)
        self.comboBox_chanType.setObjectName("comboBox_chanType")
        self.formLayout_4.setWidget(5, QtWidgets.QFormLayout.SpanningRole, self.comboBox_chanType)
        self.label_42 = QtWidgets.QLabel(self.frame_dynChannel_0)
        self.label_42.setObjectName("label_42")
        self.formLayout_4.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.label_42)
        self.comboBox_chanProfile = QtWidgets.QComboBox(self.frame_dynChannel_0)
        self.comboBox_chanProfile.setObjectName("comboBox_chanProfile")
        self.formLayout_4.setWidget(7, QtWidgets.QFormLayout.SpanningRole, self.comboBox_chanProfile)
        self.label_43 = QtWidgets.QLabel(self.frame_dynChannel_0)
        self.label_43.setObjectName("label_43")
        self.formLayout_4.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.label_43)
        self.lineEdit_chanMax = QtWidgets.QLineEdit(self.frame_dynChannel_0)
        self.lineEdit_chanMax.setObjectName("lineEdit_chanMax")
        self.formLayout_4.setWidget(9, QtWidgets.QFormLayout.LabelRole, self.lineEdit_chanMax)
        self.verticalLayout_10.addWidget(self.frame_dynChannel_0)
        spacerItem6 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_10.addItem(spacerItem6)
        self.gridLayout_4.addWidget(self.groupBox_DynamicChannels, 0, 0, 1, 1)
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_DynamicChannels)
        self.sim_conf_stack_page_Interventions = QtWidgets.QWidget()
        self.sim_conf_stack_page_Interventions.setObjectName("sim_conf_stack_page_Interventions")
        self.gridLayout_13 = QtWidgets.QGridLayout(self.sim_conf_stack_page_Interventions)
        self.gridLayout_13.setObjectName("gridLayout_13")
        self.groupBox_Interventions = QtWidgets.QGroupBox(self.sim_conf_stack_page_Interventions)
        self.groupBox_Interventions.setObjectName("groupBox_Interventions")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.groupBox_Interventions)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        spacerItem7 = QtWidgets.QSpacerItem(20, 16, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_11.addItem(spacerItem7)
        self.frame = QtWidgets.QFrame(self.groupBox_Interventions)
        self.frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.frame.setObjectName("frame")
        self.formLayout_7 = QtWidgets.QFormLayout(self.frame)
        self.formLayout_7.setObjectName("formLayout_7")
        self.rb_interventionOn = QtWidgets.QRadioButton(self.frame)
        self.rb_interventionOn.setObjectName("rb_interventionOn")
        self.formLayout_7.setWidget(0, QtWidgets.QFormLayout.SpanningRole, self.rb_interventionOn)
        self.label_44 = QtWidgets.QLabel(self.frame)
        self.label_44.setObjectName("label_44")
        self.formLayout_7.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_44)
        self.label_45 = QtWidgets.QLabel(self.frame)
        self.label_45.setObjectName("label_45")
        self.formLayout_7.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_45)
        self.label_46 = QtWidgets.QLabel(self.frame)
        self.label_46.setObjectName("label_46")
        self.formLayout_7.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.label_46)
        self.label_47 = QtWidgets.QLabel(self.frame)
        self.label_47.setObjectName("label_47")
        self.formLayout_7.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.label_47)
        self.label_48 = QtWidgets.QLabel(self.frame)
        self.label_48.setObjectName("label_48")
        self.formLayout_7.setWidget(9, QtWidgets.QFormLayout.LabelRole, self.label_48)
        self.label_49 = QtWidgets.QLabel(self.frame)
        self.label_49.setObjectName("label_49")
        self.formLayout_7.setWidget(11, QtWidgets.QFormLayout.LabelRole, self.label_49)
        self.label_50 = QtWidgets.QLabel(self.frame)
        self.label_50.setObjectName("label_50")
        self.formLayout_7.setWidget(13, QtWidgets.QFormLayout.LabelRole, self.label_50)
        self.comboBox_interventionType = QtWidgets.QComboBox(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_interventionType.sizePolicy().hasHeightForWidth())
        self.comboBox_interventionType.setSizePolicy(sizePolicy)
        self.comboBox_interventionType.setObjectName("comboBox_interventionType")
        self.formLayout_7.setWidget(2, QtWidgets.QFormLayout.SpanningRole, self.comboBox_interventionType)
        self.lineEdit_interventionStart = QtWidgets.QLineEdit(self.frame)
        self.lineEdit_interventionStart.setObjectName("lineEdit_interventionStart")
        self.formLayout_7.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.lineEdit_interventionStart)
        self.lineEdit_interventionStop = QtWidgets.QLineEdit(self.frame)
        self.lineEdit_interventionStop.setObjectName("lineEdit_interventionStop")
        self.formLayout_7.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.lineEdit_interventionStop)
        self.lineEdit_interventionRate = QtWidgets.QLineEdit(self.frame)
        self.lineEdit_interventionRate.setObjectName("lineEdit_interventionRate")
        self.formLayout_7.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.lineEdit_interventionRate)
        self.lineEdit_interventionMult = QtWidgets.QLineEdit(self.frame)
        self.lineEdit_interventionMult.setObjectName("lineEdit_interventionMult")
        self.formLayout_7.setWidget(10, QtWidgets.QFormLayout.LabelRole, self.lineEdit_interventionMult)
        self.comboBox_interventionProfile = QtWidgets.QComboBox(self.frame)
        self.comboBox_interventionProfile.setObjectName("comboBox_interventionProfile")
        self.formLayout_7.setWidget(14, QtWidgets.QFormLayout.SpanningRole, self.comboBox_interventionProfile)
        self.comboBox_interventionFunk = QtWidgets.QComboBox(self.frame)
        self.comboBox_interventionFunk.setObjectName("comboBox_interventionFunk")
        self.comboBox_interventionFunk.addItem("")
        self.comboBox_interventionFunk.addItem("")
        self.comboBox_interventionFunk.addItem("")
        self.comboBox_interventionFunk.addItem("")
        self.comboBox_interventionFunk.addItem("")
        self.comboBox_interventionFunk.addItem("")
        self.formLayout_7.setWidget(12, QtWidgets.QFormLayout.SpanningRole, self.comboBox_interventionFunk)
        self.verticalLayout_11.addWidget(self.frame)
        spacerItem8 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_11.addItem(spacerItem8)
        self.gridLayout_13.addWidget(self.groupBox_Interventions, 0, 0, 1, 1)
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_Interventions)
        self.sim_conf_stack_page_Junctions = QtWidgets.QWidget()
        self.sim_conf_stack_page_Junctions.setObjectName("sim_conf_stack_page_Junctions")
        self.gridLayout_14 = QtWidgets.QGridLayout(self.sim_conf_stack_page_Junctions)
        self.gridLayout_14.setObjectName("gridLayout_14")
        self.groupBox_Junctions = QtWidgets.QGroupBox(self.sim_conf_stack_page_Junctions)
        self.groupBox_Junctions.setObjectName("groupBox_Junctions")
        self.formLayout_6 = QtWidgets.QFormLayout(self.groupBox_Junctions)
        self.formLayout_6.setObjectName("formLayout_6")
        self.rb_vsGJ = QtWidgets.QRadioButton(self.groupBox_Junctions)
        self.rb_vsGJ.setObjectName("rb_vsGJ")
        self.formLayout_6.setWidget(4, QtWidgets.QFormLayout.SpanningRole, self.rb_vsGJ)
        self.label_25 = QtWidgets.QLabel(self.groupBox_Junctions)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.label_25.sizePolicy().hasHeightForWidth())
        self.label_25.setSizePolicy(sizePolicy)
        self.label_25.setObjectName("label_25")
        self.formLayout_6.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.label_25)
        self.label_26 = QtWidgets.QLabel(self.groupBox_Junctions)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.label_26.sizePolicy().hasHeightForWidth())
        self.label_26.setSizePolicy(sizePolicy)
        self.label_26.setObjectName("label_26")
        self.formLayout_6.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.label_26)
        self.label_27 = QtWidgets.QLabel(self.groupBox_Junctions)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.label_27.sizePolicy().hasHeightForWidth())
        self.label_27.setSizePolicy(sizePolicy)
        self.label_27.setObjectName("label_27")
        self.formLayout_6.setWidget(10, QtWidgets.QFormLayout.LabelRole, self.label_27)
        self.label_28 = QtWidgets.QLabel(self.groupBox_Junctions)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.label_28.sizePolicy().hasHeightForWidth())
        self.label_28.setSizePolicy(sizePolicy)
        self.label_28.setObjectName("label_28")
        self.formLayout_6.setWidget(12, QtWidgets.QFormLayout.LabelRole, self.label_28)
        self.label_22 = QtWidgets.QLabel(self.groupBox_Junctions)
        self.label_22.setObjectName("label_22")
        self.formLayout_6.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_22)
        self.lineEdit_GJsa = QtWidgets.QLineEdit(self.groupBox_Junctions)
        self.lineEdit_GJsa.setObjectName("lineEdit_GJsa")
        self.formLayout_6.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.lineEdit_GJsa)
        self.lineEdit_VthreshGJ = QtWidgets.QLineEdit(self.groupBox_Junctions)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.lineEdit_VthreshGJ.sizePolicy().hasHeightForWidth())
        self.lineEdit_VthreshGJ.setSizePolicy(sizePolicy)
        self.lineEdit_VthreshGJ.setObjectName("lineEdit_VthreshGJ")
        self.formLayout_6.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.lineEdit_VthreshGJ)
        self.dsb_GJmin = QtWidgets.QDoubleSpinBox(self.groupBox_Junctions)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.dsb_GJmin.sizePolicy().hasHeightForWidth())
        self.dsb_GJmin.setSizePolicy(sizePolicy)
        self.dsb_GJmin.setObjectName("dsb_GJmin")
        self.formLayout_6.setWidget(8, QtWidgets.QFormLayout.FieldRole, self.dsb_GJmin)
        self.lineEdit_TJscale = QtWidgets.QLineEdit(self.groupBox_Junctions)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.lineEdit_TJscale.sizePolicy().hasHeightForWidth())
        self.lineEdit_TJscale.setSizePolicy(sizePolicy)
        self.lineEdit_TJscale.setObjectName("lineEdit_TJscale")
        self.formLayout_6.setWidget(10, QtWidgets.QFormLayout.FieldRole, self.lineEdit_TJscale)
        self.lineEdit_adherens = QtWidgets.QLineEdit(self.groupBox_Junctions)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.lineEdit_adherens.sizePolicy().hasHeightForWidth())
        self.lineEdit_adherens.setSizePolicy(sizePolicy)
        self.lineEdit_adherens.setObjectName("lineEdit_adherens")
        self.formLayout_6.setWidget(12, QtWidgets.QFormLayout.FieldRole, self.lineEdit_adherens)
        spacerItem9 = QtWidgets.QSpacerItem(20, 16, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.formLayout_6.setItem(0, QtWidgets.QFormLayout.LabelRole, spacerItem9)
        self.gridLayout_14.addWidget(self.groupBox_Junctions, 0, 0, 1, 1)
        spacerItem10 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_14.addItem(spacerItem10, 1, 0, 1, 1)
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_Junctions)
        self.sim_conf_stack_page_Network = QtWidgets.QWidget()
        self.sim_conf_stack_page_Network.setObjectName("sim_conf_stack_page_Network")
        self.gridLayout_9 = QtWidgets.QGridLayout(self.sim_conf_stack_page_Network)
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.groupBox_Network = QtWidgets.QGroupBox(self.sim_conf_stack_page_Network)
        self.groupBox_Network.setObjectName("groupBox_Network")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout(self.groupBox_Network)
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        spacerItem11 = QtWidgets.QSpacerItem(20, 16, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_12.addItem(spacerItem11)
        self.rb_useNetwork = QtWidgets.QRadioButton(self.groupBox_Network)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.rb_useNetwork.sizePolicy().hasHeightForWidth())
        self.rb_useNetwork.setSizePolicy(sizePolicy)
        self.rb_useNetwork.setObjectName("rb_useNetwork")
        self.verticalLayout_12.addWidget(self.rb_useNetwork)
        spacerItem12 = QtWidgets.QSpacerItem(20, 16, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_12.addItem(spacerItem12)
        self.radioButton_2 = QtWidgets.QRadioButton(self.groupBox_Network)
        self.radioButton_2.setObjectName("radioButton_2")
        self.verticalLayout_12.addWidget(self.radioButton_2)
        self.widget_externalNetwork = QtWidgets.QWidget(self.groupBox_Network)
        self.widget_externalNetwork.setEnabled(False)
        self.widget_externalNetwork.setObjectName("widget_externalNetwork")
        self.verticalLayout_18 = QtWidgets.QVBoxLayout(self.widget_externalNetwork)
        self.verticalLayout_18.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_18.setObjectName("verticalLayout_18")
        self.label_61 = QtWidgets.QLabel(self.widget_externalNetwork)
        self.label_61.setObjectName("label_61")
        self.verticalLayout_18.addWidget(self.label_61)
        self.comboBox_netType = QtWidgets.QComboBox(self.widget_externalNetwork)
        self.comboBox_netType.setObjectName("comboBox_netType")
        self.comboBox_netType.addItem("")
        self.comboBox_netType.addItem("")
        self.verticalLayout_18.addWidget(self.comboBox_netType)
        self.label_21 = QtWidgets.QLabel(self.widget_externalNetwork)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.label_21.sizePolicy().hasHeightForWidth())
        self.label_21.setSizePolicy(sizePolicy)
        self.label_21.setObjectName("label_21")
        self.verticalLayout_18.addWidget(self.label_21)
        self.frame_5 = QtWidgets.QFrame(self.widget_externalNetwork)
        self.frame_5.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_5.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_5.setObjectName("frame_5")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.frame_5)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.lineEdit_NetConfig = QtWidgets.QLineEdit(self.frame_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(2)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.lineEdit_NetConfig.sizePolicy().hasHeightForWidth())
        self.lineEdit_NetConfig.setSizePolicy(sizePolicy)
        self.lineEdit_NetConfig.setObjectName("lineEdit_NetConfig")
        self.horizontalLayout_3.addWidget(self.lineEdit_NetConfig)
        self.pushButton_netBrowse = QtWidgets.QPushButton(self.frame_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.pushButton_netBrowse.sizePolicy().hasHeightForWidth())
        self.pushButton_netBrowse.setSizePolicy(sizePolicy)
        self.pushButton_netBrowse.setObjectName("pushButton_netBrowse")
        self.horizontalLayout_3.addWidget(self.pushButton_netBrowse)
        self.verticalLayout_18.addWidget(self.frame_5)
        self.verticalLayout_12.addWidget(self.widget_externalNetwork)
        spacerItem13 = QtWidgets.QSpacerItem(20, 288, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_12.addItem(spacerItem13)
        self.gridLayout_9.addWidget(self.groupBox_Network, 0, 0, 1, 1)
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_Network)
        self.sim_conf_stack_page_AdditionalPhysics = QtWidgets.QWidget()
        self.sim_conf_stack_page_AdditionalPhysics.setObjectName("sim_conf_stack_page_AdditionalPhysics")
        self.gridLayout_10 = QtWidgets.QGridLayout(self.sim_conf_stack_page_AdditionalPhysics)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.groupBox_AdditionalPhysics = QtWidgets.QGroupBox(self.sim_conf_stack_page_AdditionalPhysics)
        self.groupBox_AdditionalPhysics.setObjectName("groupBox_AdditionalPhysics")
        self.verticalLayout_13 = QtWidgets.QVBoxLayout(self.groupBox_AdditionalPhysics)
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        spacerItem14 = QtWidgets.QSpacerItem(20, 16, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_13.addItem(spacerItem14)
        self.rb_eosmoPC = QtWidgets.QRadioButton(self.groupBox_AdditionalPhysics)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.rb_eosmoPC.sizePolicy().hasHeightForWidth())
        self.rb_eosmoPC.setSizePolicy(sizePolicy)
        self.rb_eosmoPC.setObjectName("rb_eosmoPC")
        self.verticalLayout_13.addWidget(self.rb_eosmoPC)
        self.rb_flow = QtWidgets.QRadioButton(self.groupBox_AdditionalPhysics)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.rb_flow.sizePolicy().hasHeightForWidth())
        self.rb_flow.setSizePolicy(sizePolicy)
        self.rb_flow.setObjectName("rb_flow")
        self.verticalLayout_13.addWidget(self.rb_flow)
        self.rb_deform = QtWidgets.QRadioButton(self.groupBox_AdditionalPhysics)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.rb_deform.sizePolicy().hasHeightForWidth())
        self.rb_deform.setSizePolicy(sizePolicy)
        self.rb_deform.setObjectName("rb_deform")
        self.verticalLayout_13.addWidget(self.rb_deform)
        self.rb_osmosis = QtWidgets.QRadioButton(self.groupBox_AdditionalPhysics)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.rb_osmosis.sizePolicy().hasHeightForWidth())
        self.rb_osmosis.setSizePolicy(sizePolicy)
        self.rb_osmosis.setObjectName("rb_osmosis")
        self.verticalLayout_13.addWidget(self.rb_osmosis)
        self.rb_dynNoise = QtWidgets.QRadioButton(self.groupBox_AdditionalPhysics)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.rb_dynNoise.sizePolicy().hasHeightForWidth())
        self.rb_dynNoise.setSizePolicy(sizePolicy)
        self.rb_dynNoise.setObjectName("rb_dynNoise")
        self.verticalLayout_13.addWidget(self.rb_dynNoise)
        self.widget_2 = QtWidgets.QWidget(self.groupBox_AdditionalPhysics)
        self.widget_2.setObjectName("widget_2")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.widget_2)
        self.horizontalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_24 = QtWidgets.QLabel(self.widget_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.label_24.sizePolicy().hasHeightForWidth())
        self.label_24.setSizePolicy(sizePolicy)
        self.label_24.setObjectName("label_24")
        self.horizontalLayout_4.addWidget(self.label_24)
        self.dsb_staticNoise = QtWidgets.QDoubleSpinBox(self.widget_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.dsb_staticNoise.sizePolicy().hasHeightForWidth())
        self.dsb_staticNoise.setSizePolicy(sizePolicy)
        self.dsb_staticNoise.setObjectName("dsb_staticNoise")
        self.horizontalLayout_4.addWidget(self.dsb_staticNoise)
        self.verticalLayout_13.addWidget(self.widget_2)
        self.gridLayout_10.addWidget(self.groupBox_AdditionalPhysics, 0, 0, 1, 1)
        spacerItem15 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_10.addItem(spacerItem15, 1, 0, 1, 1)
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_AdditionalPhysics)
        self.sim_conf_stack_page_Tools = QtWidgets.QWidget()
        self.sim_conf_stack_page_Tools.setObjectName("sim_conf_stack_page_Tools")
        self.gridLayout_15 = QtWidgets.QGridLayout(self.sim_conf_stack_page_Tools)
        self.gridLayout_15.setObjectName("gridLayout_15")
        self.groupBox_Tools = QtWidgets.QGroupBox(self.sim_conf_stack_page_Tools)
        self.groupBox_Tools.setObjectName("groupBox_Tools")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout(self.groupBox_Tools)
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        spacerItem16 = QtWidgets.QSpacerItem(20, 16, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_14.addItem(spacerItem16)
        self.rb_Goldman = QtWidgets.QRadioButton(self.groupBox_Tools)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.rb_Goldman.sizePolicy().hasHeightForWidth())
        self.rb_Goldman.setSizePolicy(sizePolicy)
        self.rb_Goldman.setObjectName("rb_Goldman")
        self.verticalLayout_14.addWidget(self.rb_Goldman)
        spacerItem17 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_14.addItem(spacerItem17)
        self.gridLayout_15.addWidget(self.groupBox_Tools, 0, 0, 1, 1)
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_Tools)
        self.sim_conf_stack_page_Advanced = QtWidgets.QWidget()
        self.sim_conf_stack_page_Advanced.setObjectName("sim_conf_stack_page_Advanced")
        self.gridLayout_16 = QtWidgets.QGridLayout(self.sim_conf_stack_page_Advanced)
        self.gridLayout_16.setObjectName("gridLayout_16")
        self.groupBox_2 = QtWidgets.QGroupBox(self.sim_conf_stack_page_Advanced)
        self.groupBox_2.setObjectName("groupBox_2")
        self.verticalLayout_15 = QtWidgets.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_15.setObjectName("verticalLayout_15")
        spacerItem18 = QtWidgets.QSpacerItem(20, 16, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_15.addItem(spacerItem18)
        self.label_29 = QtWidgets.QLabel(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.label_29.sizePolicy().hasHeightForWidth())
        self.label_29.setSizePolicy(sizePolicy)
        self.label_29.setObjectName("label_29")
        self.verticalLayout_15.addWidget(self.label_29)
        self.lineEdit_NaKATPaseMax = QtWidgets.QLineEdit(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.lineEdit_NaKATPaseMax.sizePolicy().hasHeightForWidth())
        self.lineEdit_NaKATPaseMax.setSizePolicy(sizePolicy)
        self.lineEdit_NaKATPaseMax.setObjectName("lineEdit_NaKATPaseMax")
        self.verticalLayout_15.addWidget(self.lineEdit_NaKATPaseMax)
        self.label_32 = QtWidgets.QLabel(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.label_32.sizePolicy().hasHeightForWidth())
        self.label_32.setSizePolicy(sizePolicy)
        self.label_32.setObjectName("label_32")
        self.verticalLayout_15.addWidget(self.label_32)
        self.lineEdit_CaATPaseMax = QtWidgets.QLineEdit(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.lineEdit_CaATPaseMax.sizePolicy().hasHeightForWidth())
        self.lineEdit_CaATPaseMax.setSizePolicy(sizePolicy)
        self.lineEdit_CaATPaseMax.setObjectName("lineEdit_CaATPaseMax")
        self.verticalLayout_15.addWidget(self.lineEdit_CaATPaseMax)
        self.label_33 = QtWidgets.QLabel(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.label_33.sizePolicy().hasHeightForWidth())
        self.label_33.setSizePolicy(sizePolicy)
        self.label_33.setObjectName("label_33")
        self.verticalLayout_15.addWidget(self.label_33)
        self.dsb_gaussian = QtWidgets.QDoubleSpinBox(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.dsb_gaussian.sizePolicy().hasHeightForWidth())
        self.dsb_gaussian.setSizePolicy(sizePolicy)
        self.dsb_gaussian.setDecimals(1)
        self.dsb_gaussian.setMaximum(2.0)
        self.dsb_gaussian.setSingleStep(0.1)
        self.dsb_gaussian.setObjectName("dsb_gaussian")
        self.verticalLayout_15.addWidget(self.dsb_gaussian)
        self.rb_smoothConcs = QtWidgets.QRadioButton(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.rb_smoothConcs.sizePolicy().hasHeightForWidth())
        self.rb_smoothConcs.setSizePolicy(sizePolicy)
        self.rb_smoothConcs.setObjectName("rb_smoothConcs")
        self.verticalLayout_15.addWidget(self.rb_smoothConcs)
        self.rb_subsVmem = QtWidgets.QRadioButton(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.rb_subsVmem.sizePolicy().hasHeightForWidth())
        self.rb_subsVmem.setSizePolicy(sizePolicy)
        self.rb_subsVmem.setObjectName("rb_subsVmem")
        self.verticalLayout_15.addWidget(self.rb_subsVmem)
        spacerItem19 = QtWidgets.QSpacerItem(20, 16, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_15.addItem(spacerItem19)
        self.label_40 = QtWidgets.QLabel(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.label_40.sizePolicy().hasHeightForWidth())
        self.label_40.setSizePolicy(sizePolicy)
        self.label_40.setObjectName("label_40")
        self.verticalLayout_15.addWidget(self.label_40)
        self.dsb_timeAccel = QtWidgets.QDoubleSpinBox(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.dsb_timeAccel.sizePolicy().hasHeightForWidth())
        self.dsb_timeAccel.setSizePolicy(sizePolicy)
        self.dsb_timeAccel.setDecimals(1)
        self.dsb_timeAccel.setMaximum(5000.0)
        self.dsb_timeAccel.setObjectName("dsb_timeAccel")
        self.verticalLayout_15.addWidget(self.dsb_timeAccel)
        self.gridLayout_16.addWidget(self.groupBox_2, 0, 0, 1, 1)
        spacerItem20 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_16.addItem(spacerItem20, 1, 0, 1, 1)
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_Advanced)
        self.sim_conf_stack_page_Results = QtWidgets.QWidget()
        self.sim_conf_stack_page_Results.setObjectName("sim_conf_stack_page_Results")
        self.gridLayout_11 = QtWidgets.QGridLayout(self.sim_conf_stack_page_Results)
        self.gridLayout_11.setObjectName("gridLayout_11")
        self.groupBox_resultsSettings = QtWidgets.QGroupBox(self.sim_conf_stack_page_Results)
        self.groupBox_resultsSettings.setObjectName("groupBox_resultsSettings")
        self.verticalLayout_16 = QtWidgets.QVBoxLayout(self.groupBox_resultsSettings)
        self.verticalLayout_16.setObjectName("verticalLayout_16")
        spacerItem21 = QtWidgets.QSpacerItem(20, 16, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_16.addItem(spacerItem21)
        self.rb_autosavePlots = QtWidgets.QRadioButton(self.groupBox_resultsSettings)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.rb_autosavePlots.sizePolicy().hasHeightForWidth())
        self.rb_autosavePlots.setSizePolicy(sizePolicy)
        self.rb_autosavePlots.setObjectName("rb_autosavePlots")
        self.verticalLayout_16.addWidget(self.rb_autosavePlots)
        self.rb_enableAni = QtWidgets.QRadioButton(self.groupBox_resultsSettings)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.rb_enableAni.sizePolicy().hasHeightForWidth())
        self.rb_enableAni.setSizePolicy(sizePolicy)
        self.rb_enableAni.setObjectName("rb_enableAni")
        self.verticalLayout_16.addWidget(self.rb_enableAni)
        self.rb_showCells = QtWidgets.QRadioButton(self.groupBox_resultsSettings)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.rb_showCells.sizePolicy().hasHeightForWidth())
        self.rb_showCells.setSizePolicy(sizePolicy)
        self.rb_showCells.setObjectName("rb_showCells")
        self.verticalLayout_16.addWidget(self.rb_showCells)
        self.rb_enumerateCells = QtWidgets.QRadioButton(self.groupBox_resultsSettings)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.rb_enumerateCells.sizePolicy().hasHeightForWidth())
        self.rb_enumerateCells.setSizePolicy(sizePolicy)
        self.rb_enumerateCells.setObjectName("rb_enumerateCells")
        self.verticalLayout_16.addWidget(self.rb_enumerateCells)
        self.rb_IOverlay = QtWidgets.QRadioButton(self.groupBox_resultsSettings)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.rb_IOverlay.sizePolicy().hasHeightForWidth())
        self.rb_IOverlay.setSizePolicy(sizePolicy)
        self.rb_IOverlay.setObjectName("rb_IOverlay")
        self.verticalLayout_16.addWidget(self.rb_IOverlay)
        spacerItem22 = QtWidgets.QSpacerItem(20, 16, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_16.addItem(spacerItem22)
        self.label_13 = QtWidgets.QLabel(self.groupBox_resultsSettings)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.label_13.sizePolicy().hasHeightForWidth())
        self.label_13.setSizePolicy(sizePolicy)
        self.label_13.setObjectName("label_13")
        self.verticalLayout_16.addWidget(self.label_13)
        self.sb_plotCell = QtWidgets.QSpinBox(self.groupBox_resultsSettings)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.sb_plotCell.sizePolicy().hasHeightForWidth())
        self.sb_plotCell.setSizePolicy(sizePolicy)
        self.sb_plotCell.setMaximum(5000)
        self.sb_plotCell.setObjectName("sb_plotCell")
        self.verticalLayout_16.addWidget(self.sb_plotCell)
        self.gridLayout_11.addWidget(self.groupBox_resultsSettings, 0, 0, 1, 1)
        spacerItem23 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_11.addItem(spacerItem23, 1, 0, 1, 1)
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_Results)
        self.sim_conf_stack_page_DataExport = QtWidgets.QWidget()
        self.sim_conf_stack_page_DataExport.setObjectName("sim_conf_stack_page_DataExport")
        self.gridLayout_12 = QtWidgets.QGridLayout(self.sim_conf_stack_page_DataExport)
        self.gridLayout_12.setObjectName("gridLayout_12")
        self.groupBox_5 = QtWidgets.QGroupBox(self.sim_conf_stack_page_DataExport)
        self.groupBox_5.setObjectName("groupBox_5")
        self.formLayout_12 = QtWidgets.QFormLayout(self.groupBox_5)
        self.formLayout_12.setObjectName("formLayout_12")
        self.label_66 = QtWidgets.QLabel(self.groupBox_5)
        self.label_66.setObjectName("label_66")
        self.formLayout_12.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_66)
        self.comboBox_4 = QtWidgets.QComboBox(self.groupBox_5)
        self.comboBox_4.setObjectName("comboBox_4")
        self.comboBox_4.addItem("")
        self.comboBox_4.addItem("")
        self.formLayout_12.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.comboBox_4)
        spacerItem24 = QtWidgets.QSpacerItem(20, 16, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.formLayout_12.setItem(0, QtWidgets.QFormLayout.LabelRole, spacerItem24)
        self.gridLayout_12.addWidget(self.groupBox_5, 0, 0, 1, 1)
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_DataExport)
        self.sim_conf_stack_page_LinePlots = QtWidgets.QWidget()
        self.sim_conf_stack_page_LinePlots.setObjectName("sim_conf_stack_page_LinePlots")
        self.gridLayout_19 = QtWidgets.QGridLayout(self.sim_conf_stack_page_LinePlots)
        self.gridLayout_19.setObjectName("gridLayout_19")
        self.groupBox = QtWidgets.QGroupBox(self.sim_conf_stack_page_LinePlots)
        self.groupBox.setObjectName("groupBox")
        self.formLayout_3 = QtWidgets.QFormLayout(self.groupBox)
        self.formLayout_3.setObjectName("formLayout_3")
        self.label_63 = QtWidgets.QLabel(self.groupBox)
        self.label_63.setObjectName("label_63")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_63)
        spacerItem25 = QtWidgets.QSpacerItem(20, 16, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.formLayout_3.setItem(0, QtWidgets.QFormLayout.LabelRole, spacerItem25)
        self.comboBox = QtWidgets.QComboBox(self.groupBox)
        self.comboBox.setObjectName("comboBox")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.SpanningRole, self.comboBox)
        spacerItem26 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.formLayout_3.setItem(3, QtWidgets.QFormLayout.LabelRole, spacerItem26)
        self.label_67 = QtWidgets.QLabel(self.groupBox)
        self.label_67.setObjectName("label_67")
        self.formLayout_3.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.label_67)
        self.spinBox = QtWidgets.QSpinBox(self.groupBox)
        self.spinBox.setObjectName("spinBox")
        self.formLayout_3.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.spinBox)
        self.gridLayout_19.addWidget(self.groupBox, 0, 0, 1, 1)
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_LinePlots)
        self.sim_conf_stack_page_2DPlots = QtWidgets.QWidget()
        self.sim_conf_stack_page_2DPlots.setObjectName("sim_conf_stack_page_2DPlots")
        self.gridLayout_18 = QtWidgets.QGridLayout(self.sim_conf_stack_page_2DPlots)
        self.gridLayout_18.setObjectName("gridLayout_18")
        self.groupBox_3 = QtWidgets.QGroupBox(self.sim_conf_stack_page_2DPlots)
        self.groupBox_3.setObjectName("groupBox_3")
        self.formLayout_13 = QtWidgets.QFormLayout(self.groupBox_3)
        self.formLayout_13.setObjectName("formLayout_13")
        self.label_64 = QtWidgets.QLabel(self.groupBox_3)
        self.label_64.setObjectName("label_64")
        self.formLayout_13.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_64)
        self.comboBox_2 = QtWidgets.QComboBox(self.groupBox_3)
        self.comboBox_2.setObjectName("comboBox_2")
        self.comboBox_2.addItem("")
        self.comboBox_2.addItem("")
        self.comboBox_2.addItem("")
        self.comboBox_2.addItem("")
        self.comboBox_2.addItem("")
        self.comboBox_2.addItem("")
        self.comboBox_2.addItem("")
        self.formLayout_13.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.comboBox_2)
        spacerItem27 = QtWidgets.QSpacerItem(20, 16, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Maximum)
        self.formLayout_13.setItem(0, QtWidgets.QFormLayout.LabelRole, spacerItem27)
        self.gridLayout_18.addWidget(self.groupBox_3, 0, 0, 1, 1)
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_2DPlots)
        self.sim_conf_stack_page_Animations = QtWidgets.QWidget()
        self.sim_conf_stack_page_Animations.setObjectName("sim_conf_stack_page_Animations")
        self.gridLayout_20 = QtWidgets.QGridLayout(self.sim_conf_stack_page_Animations)
        self.gridLayout_20.setObjectName("gridLayout_20")
        self.groupBox_4 = QtWidgets.QGroupBox(self.sim_conf_stack_page_Animations)
        self.groupBox_4.setObjectName("groupBox_4")
        self.formLayout_14 = QtWidgets.QFormLayout(self.groupBox_4)
        self.formLayout_14.setObjectName("formLayout_14")
        self.label_65 = QtWidgets.QLabel(self.groupBox_4)
        self.label_65.setObjectName("label_65")
        self.formLayout_14.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_65)
        self.comboBox_3 = QtWidgets.QComboBox(self.groupBox_4)
        self.comboBox_3.setObjectName("comboBox_3")
        self.comboBox_3.addItem("")
        self.comboBox_3.addItem("")
        self.comboBox_3.addItem("")
        self.comboBox_3.addItem("")
        self.comboBox_3.addItem("")
        self.comboBox_3.addItem("")
        self.comboBox_3.addItem("")
        self.comboBox_3.setItemText(6, "")
        self.formLayout_14.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.comboBox_3)
        spacerItem28 = QtWidgets.QSpacerItem(20, 16, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.formLayout_14.setItem(0, QtWidgets.QFormLayout.LabelRole, spacerItem28)
        self.gridLayout_20.addWidget(self.groupBox_4, 0, 0, 1, 1)
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_Animations)
        self.sim_conf_stack_page_NetworkSubstance = QtWidgets.QWidget()
        self.sim_conf_stack_page_NetworkSubstance.setObjectName("sim_conf_stack_page_NetworkSubstance")
        self.groupBox_6 = QtWidgets.QGroupBox(self.sim_conf_stack_page_NetworkSubstance)
        self.groupBox_6.setGeometry(QtCore.QRect(20, 40, 311, 341))
        self.groupBox_6.setObjectName("groupBox_6")
        self.label_72 = QtWidgets.QLabel(self.groupBox_6)
        self.label_72.setGeometry(QtCore.QRect(20, 70, 78, 19))
        self.label_72.setObjectName("label_72")
        self.lineEdit_substName = QtWidgets.QLineEdit(self.groupBox_6)
        self.lineEdit_substName.setGeometry(QtCore.QRect(90, 70, 113, 29))
        self.lineEdit_substName.setObjectName("lineEdit_substName")
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_NetworkSubstance)
        self.sim_conf_stack_page_NetworkReaction = QtWidgets.QWidget()
        self.sim_conf_stack_page_NetworkReaction.setObjectName("sim_conf_stack_page_NetworkReaction")
        self.groupBox_7 = QtWidgets.QGroupBox(self.sim_conf_stack_page_NetworkReaction)
        self.groupBox_7.setGeometry(QtCore.QRect(20, 50, 311, 331))
        self.groupBox_7.setObjectName("groupBox_7")
        self.label_71 = QtWidgets.QLabel(self.groupBox_7)
        self.label_71.setGeometry(QtCore.QRect(40, 90, 78, 19))
        self.label_71.setObjectName("label_71")
        self.lineEdit_reactName = QtWidgets.QLineEdit(self.groupBox_7)
        self.lineEdit_reactName.setGeometry(QtCore.QRect(110, 90, 113, 29))
        self.lineEdit_reactName.setObjectName("lineEdit_reactName")
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_NetworkReaction)
        self.sim_conf_stack_page_NetworkTransporter = QtWidgets.QWidget()
        self.sim_conf_stack_page_NetworkTransporter.setObjectName("sim_conf_stack_page_NetworkTransporter")
        self.groupBox_8 = QtWidgets.QGroupBox(self.sim_conf_stack_page_NetworkTransporter)
        self.groupBox_8.setGeometry(QtCore.QRect(20, 40, 291, 381))
        self.groupBox_8.setObjectName("groupBox_8")
        self.label_70 = QtWidgets.QLabel(self.groupBox_8)
        self.label_70.setGeometry(QtCore.QRect(20, 80, 78, 19))
        self.label_70.setObjectName("label_70")
        self.lineEdit_transpName = QtWidgets.QLineEdit(self.groupBox_8)
        self.lineEdit_transpName.setGeometry(QtCore.QRect(110, 80, 113, 29))
        self.lineEdit_transpName.setObjectName("lineEdit_transpName")
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_NetworkTransporter)
        self.sim_conf_stack_page_NetworkChannel = QtWidgets.QWidget()
        self.sim_conf_stack_page_NetworkChannel.setObjectName("sim_conf_stack_page_NetworkChannel")
        self.groupBox_9 = QtWidgets.QGroupBox(self.sim_conf_stack_page_NetworkChannel)
        self.groupBox_9.setGeometry(QtCore.QRect(50, 70, 461, 161))
        self.groupBox_9.setObjectName("groupBox_9")
        self.lineEdit_chanNetName = QtWidgets.QLineEdit(self.groupBox_9)
        self.lineEdit_chanNetName.setGeometry(QtCore.QRect(180, 60, 113, 31))
        self.lineEdit_chanNetName.setObjectName("lineEdit_chanNetName")
        self.label_69 = QtWidgets.QLabel(self.sim_conf_stack_page_NetworkChannel)
        self.label_69.setGeometry(QtCore.QRect(60, 140, 78, 19))
        self.label_69.setObjectName("label_69")
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_NetworkChannel)
        self.sim_conf_stack_page_NetworkModulator = QtWidgets.QWidget()
        self.sim_conf_stack_page_NetworkModulator.setObjectName("sim_conf_stack_page_NetworkModulator")
        self.gridLayout_17 = QtWidgets.QGridLayout(self.sim_conf_stack_page_NetworkModulator)
        self.gridLayout_17.setObjectName("gridLayout_17")
        spacerItem29 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Maximum)
        self.gridLayout_17.addItem(spacerItem29, 0, 0, 1, 1)
        self.groupBox_10 = QtWidgets.QGroupBox(self.sim_conf_stack_page_NetworkModulator)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setWeight(75)
        font.setBold(True)
        self.groupBox_10.setFont(font)
        self.groupBox_10.setObjectName("groupBox_10")
        self.formLayout_15 = QtWidgets.QFormLayout(self.groupBox_10)
        self.formLayout_15.setObjectName("formLayout_15")
        self.label_68 = QtWidgets.QLabel(self.groupBox_10)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_68.setFont(font)
        self.label_68.setObjectName("label_68")
        self.formLayout_15.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_68)
        self.lineEdit_modName = QtWidgets.QLineEdit(self.groupBox_10)
        self.lineEdit_modName.setObjectName("lineEdit_modName")
        self.formLayout_15.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.lineEdit_modName)
        self.gridLayout_17.addWidget(self.groupBox_10, 1, 0, 1, 1)
        self.sim_conf_stack.addWidget(self.sim_conf_stack_page_NetworkModulator)
        self.sim_conf_stack_area.setWidget(self.sim_conf_stack)
        self.gridLayout.addWidget(self.sim_conf_stack_area, 0, 1, 1, 1)
        self.sim_tab = QBetseeSimmerTabWidget(self.centralWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(3)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.sim_tab.sizePolicy().hasHeightForWidth())
        self.sim_tab.setSizePolicy(sizePolicy)
        self.sim_tab.setElideMode(QtCore.Qt.ElideRight)
        self.sim_tab.setTabBarAutoHide(False)
        self.sim_tab.setObjectName("sim_tab")
        self.sim_cmd_tab_run_area = QtWidgets.QScrollArea()
        self.sim_cmd_tab_run_area.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.sim_cmd_tab_run_area.setWidgetResizable(True)
        self.sim_cmd_tab_run_area.setObjectName("sim_cmd_tab_run_area")
        self.sim_cmd_tab_run = QtWidgets.QWidget()
        self.sim_cmd_tab_run.setGeometry(QtCore.QRect(0, 0, 756, 800))
        self.sim_cmd_tab_run.setProperty("is_page", True)
        self.sim_cmd_tab_run.setObjectName("sim_cmd_tab_run")
        self.gridLayout_30 = QtWidgets.QGridLayout(self.sim_cmd_tab_run)
        self.gridLayout_30.setObjectName("gridLayout_30")
        self.sim_run_player = QtWidgets.QGroupBox(self.sim_cmd_tab_run)
        self.sim_run_player.setObjectName("sim_run_player")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.sim_run_player)
        self.verticalLayout.setObjectName("verticalLayout")
        self.sim_run_player_progress = QBetseeProgressBar(self.sim_run_player)
        self.sim_run_player_progress.setAlignment(QtCore.Qt.AlignCenter)
        self.sim_run_player_progress.setObjectName("sim_run_player_progress")
        self.verticalLayout.addWidget(self.sim_run_player_progress)
        self.sim_run_player_status = QtWidgets.QLabel(self.sim_run_player)
        self.sim_run_player_status.setWordWrap(True)
        self.sim_run_player_status.setObjectName("sim_run_player_status")
        self.verticalLayout.addWidget(self.sim_run_player_status)
        self.sim_run_player_substatus_group = QtWidgets.QWidget(self.sim_run_player)
        self.sim_run_player_substatus_group.setProperty("is_group", True)
        self.sim_run_player_substatus_group.setObjectName("sim_run_player_substatus_group")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.sim_run_player_substatus_group)
        self.horizontalLayout.setSpacing(8)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.sim_run_player_substatus_icon = QtWidgets.QLabel(self.sim_run_player_substatus_group)
        self.sim_run_player_substatus_icon.setText("")
        self.sim_run_player_substatus_icon.setPixmap(QtGui.QPixmap(":/icon/entypo+/level-down.svg"))
        self.sim_run_player_substatus_icon.setObjectName("sim_run_player_substatus_icon")
        self.horizontalLayout.addWidget(self.sim_run_player_substatus_icon)
        self.sim_run_player_substatus = QtWidgets.QLabel(self.sim_run_player_substatus_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_player_substatus.sizePolicy().hasHeightForWidth())
        self.sim_run_player_substatus.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.sim_run_player_substatus.setFont(font)
        self.sim_run_player_substatus.setObjectName("sim_run_player_substatus")
        self.horizontalLayout.addWidget(self.sim_run_player_substatus)
        self.verticalLayout.addWidget(self.sim_run_player_substatus_group)
        self.sim_run_player_toolbar_frame = QtWidgets.QFrame(self.sim_run_player)
        self.sim_run_player_toolbar_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.sim_run_player_toolbar_frame.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.sim_run_player_toolbar_frame.setObjectName("sim_run_player_toolbar_frame")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.sim_run_player_toolbar_frame)
        self.verticalLayout_3.setSpacing(0)
        self.verticalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.sim_run_player_toolbar  = QtWidgets.QToolBar(self.sim_run_player_toolbar_frame)
        self.sim_run_player_toolbar .setIconSize(QtCore.QSize(32, 32))
        self.sim_run_player_toolbar .setObjectName("sim_run_player_toolbar ")
        self.verticalLayout_3.addWidget(self.sim_run_player_toolbar )
        self.verticalLayout.addWidget(self.sim_run_player_toolbar_frame)
        self.gridLayout_30.addWidget(self.sim_run_player, 0, 0, 1, 1)
        spacerItem30 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_30.addItem(spacerItem30, 4, 0, 1, 1)
        self.sim_run_queue_group = QtWidgets.QGroupBox(self.sim_cmd_tab_run)
        self.sim_run_queue_group.setObjectName("sim_run_queue_group")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.sim_run_queue_group)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.sim_run_queue_init = QtWidgets.QLabel(self.sim_run_queue_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_init.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_init.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_run_queue_init.setFont(font)
        self.sim_run_queue_init.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.sim_run_queue_init.setObjectName("sim_run_queue_init")
        self.gridLayout_5.addWidget(self.sim_run_queue_init, 5, 1, 1, 2)
        self.sim_run_queue_sim_export = QtWidgets.QCheckBox(self.sim_run_queue_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_sim_export.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_sim_export.setSizePolicy(sizePolicy)
        self.sim_run_queue_sim_export.setText("")
        self.sim_run_queue_sim_export.setObjectName("sim_run_queue_sim_export")
        self.gridLayout_5.addWidget(self.sim_run_queue_sim_export, 7, 6, 1, 1)
        self.sim_run_queue_sim_model_cell = QtWidgets.QWidget(self.sim_run_queue_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_sim_model_cell.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_sim_model_cell.setSizePolicy(sizePolicy)
        self.sim_run_queue_sim_model_cell.setObjectName("sim_run_queue_sim_model_cell")
        self.horizontalLayout_34 = QtWidgets.QHBoxLayout(self.sim_run_queue_sim_model_cell)
        self.horizontalLayout_34.setSpacing(0)
        self.horizontalLayout_34.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_34.setObjectName("horizontalLayout_34")
        self.sim_run_queue_sim_model = QtWidgets.QCheckBox(self.sim_run_queue_sim_model_cell)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_sim_model.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_sim_model.setSizePolicy(sizePolicy)
        self.sim_run_queue_sim_model.setText("")
        self.sim_run_queue_sim_model.setObjectName("sim_run_queue_sim_model")
        self.horizontalLayout_34.addWidget(self.sim_run_queue_sim_model)
        spacerItem31 = QtWidgets.QSpacerItem(5, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_34.addItem(spacerItem31)
        self.sim_run_queue_sim_model_lock = QtWidgets.QToolButton(self.sim_run_queue_sim_model_cell)
        self.sim_run_queue_sim_model_lock.setText("")
        icon18 = QtGui.QIcon()
        icon18.addFile(":/icon/open_iconic/lock-unlocked.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon18.addFile(":/icon/open_iconic/lock-locked.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.sim_run_queue_sim_model_lock.setIcon(icon18)
        self.sim_run_queue_sim_model_lock.setCheckable(True)
        self.sim_run_queue_sim_model_lock.setAutoRaise(True)
        self.sim_run_queue_sim_model_lock.setObjectName("sim_run_queue_sim_model_lock")
        self.horizontalLayout_34.addWidget(self.sim_run_queue_sim_model_lock)
        spacerItem32 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_34.addItem(spacerItem32)
        self.gridLayout_5.addWidget(self.sim_run_queue_sim_model_cell, 7, 3, 1, 2)
        self.sim_run_queue_seed = QtWidgets.QLabel(self.sim_run_queue_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_seed.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_seed.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_run_queue_seed.setFont(font)
        self.sim_run_queue_seed.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.sim_run_queue_seed.setObjectName("sim_run_queue_seed")
        self.gridLayout_5.addWidget(self.sim_run_queue_seed, 4, 1, 1, 1)
        self.sim_run_queue_head_export = QtWidgets.QLabel(self.sim_run_queue_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_head_export.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_head_export.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_run_queue_head_export.setFont(font)
        self.sim_run_queue_head_export.setObjectName("sim_run_queue_head_export")
        self.gridLayout_5.addWidget(self.sim_run_queue_head_export, 1, 6, 2, 1)
        self.sim_run_queue_seed_model_cell = QtWidgets.QWidget(self.sim_run_queue_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_seed_model_cell.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_seed_model_cell.setSizePolicy(sizePolicy)
        self.sim_run_queue_seed_model_cell.setObjectName("sim_run_queue_seed_model_cell")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.sim_run_queue_seed_model_cell)
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.sim_run_queue_seed_model = QtWidgets.QCheckBox(self.sim_run_queue_seed_model_cell)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_seed_model.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_seed_model.setSizePolicy(sizePolicy)
        self.sim_run_queue_seed_model.setText("")
        self.sim_run_queue_seed_model.setObjectName("sim_run_queue_seed_model")
        self.horizontalLayout_2.addWidget(self.sim_run_queue_seed_model)
        spacerItem33 = QtWidgets.QSpacerItem(5, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem33)
        self.sim_run_queue_seed_model_lock = QtWidgets.QToolButton(self.sim_run_queue_seed_model_cell)
        self.sim_run_queue_seed_model_lock.setText("")
        self.sim_run_queue_seed_model_lock.setIcon(icon18)
        self.sim_run_queue_seed_model_lock.setCheckable(True)
        self.sim_run_queue_seed_model_lock.setAutoRaise(True)
        self.sim_run_queue_seed_model_lock.setObjectName("sim_run_queue_seed_model_lock")
        self.horizontalLayout_2.addWidget(self.sim_run_queue_seed_model_lock)
        spacerItem34 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem34)
        self.gridLayout_5.addWidget(self.sim_run_queue_seed_model_cell, 4, 3, 1, 2)
        self.sim_run_queue_init_export = QtWidgets.QCheckBox(self.sim_run_queue_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_init_export.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_init_export.setSizePolicy(sizePolicy)
        self.sim_run_queue_init_export.setText("")
        self.sim_run_queue_init_export.setObjectName("sim_run_queue_init_export")
        self.gridLayout_5.addWidget(self.sim_run_queue_init_export, 5, 6, 1, 1)
        self.sim_run_queue_init_model_cell = QtWidgets.QWidget(self.sim_run_queue_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_init_model_cell.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_init_model_cell.setSizePolicy(sizePolicy)
        self.sim_run_queue_init_model_cell.setObjectName("sim_run_queue_init_model_cell")
        self.horizontalLayout_31 = QtWidgets.QHBoxLayout(self.sim_run_queue_init_model_cell)
        self.horizontalLayout_31.setSpacing(0)
        self.horizontalLayout_31.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_31.setObjectName("horizontalLayout_31")
        self.sim_run_queue_init_model = QtWidgets.QCheckBox(self.sim_run_queue_init_model_cell)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_init_model.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_init_model.setSizePolicy(sizePolicy)
        self.sim_run_queue_init_model.setText("")
        self.sim_run_queue_init_model.setObjectName("sim_run_queue_init_model")
        self.horizontalLayout_31.addWidget(self.sim_run_queue_init_model)
        spacerItem35 = QtWidgets.QSpacerItem(5, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_31.addItem(spacerItem35)
        self.sim_run_queue_init_model_lock = QtWidgets.QToolButton(self.sim_run_queue_init_model_cell)
        self.sim_run_queue_init_model_lock.setText("")
        self.sim_run_queue_init_model_lock.setIcon(icon18)
        self.sim_run_queue_init_model_lock.setCheckable(True)
        self.sim_run_queue_init_model_lock.setAutoRaise(True)
        self.sim_run_queue_init_model_lock.setObjectName("sim_run_queue_init_model_lock")
        self.horizontalLayout_31.addWidget(self.sim_run_queue_init_model_lock)
        spacerItem36 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_31.addItem(spacerItem36)
        self.gridLayout_5.addWidget(self.sim_run_queue_init_model_cell, 5, 3, 1, 2)
        self.sim_run_queue_init_index = QtWidgets.QLabel(self.sim_run_queue_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_init_index.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_init_index.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_run_queue_init_index.setFont(font)
        self.sim_run_queue_init_index.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.sim_run_queue_init_index.setObjectName("sim_run_queue_init_index")
        self.gridLayout_5.addWidget(self.sim_run_queue_init_index, 5, 0, 1, 1)
        self.sim_run_queue_head_model = QtWidgets.QLabel(self.sim_run_queue_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_head_model.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_head_model.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_run_queue_head_model.setFont(font)
        self.sim_run_queue_head_model.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.sim_run_queue_head_model.setObjectName("sim_run_queue_head_model")
        self.gridLayout_5.addWidget(self.sim_run_queue_head_model, 1, 3, 2, 1)
        self.sim_run_queue_sim_index = QtWidgets.QLabel(self.sim_run_queue_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_sim_index.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_sim_index.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_run_queue_sim_index.setFont(font)
        self.sim_run_queue_sim_index.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.sim_run_queue_sim_index.setObjectName("sim_run_queue_sim_index")
        self.gridLayout_5.addWidget(self.sim_run_queue_sim_index, 7, 0, 1, 1)
        self.sim_run_queue_sim = QtWidgets.QLabel(self.sim_run_queue_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_sim.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_sim.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_run_queue_sim.setFont(font)
        self.sim_run_queue_sim.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.sim_run_queue_sim.setObjectName("sim_run_queue_sim")
        self.gridLayout_5.addWidget(self.sim_run_queue_sim, 7, 1, 1, 2)
        self.sim_run_queue_seed_index = QtWidgets.QLabel(self.sim_run_queue_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_seed_index.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_seed_index.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_run_queue_seed_index.setFont(font)
        self.sim_run_queue_seed_index.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.sim_run_queue_seed_index.setObjectName("sim_run_queue_seed_index")
        self.gridLayout_5.addWidget(self.sim_run_queue_seed_index, 4, 0, 1, 1)
        self.sim_run_queue_head_phase = QtWidgets.QLabel(self.sim_run_queue_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_head_phase.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_head_phase.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_run_queue_head_phase.setFont(font)
        self.sim_run_queue_head_phase.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.sim_run_queue_head_phase.setObjectName("sim_run_queue_head_phase")
        self.gridLayout_5.addWidget(self.sim_run_queue_head_phase, 1, 1, 2, 1)
        self.sim_run_queue_head_line_bottom = QtWidgets.QFrame(self.sim_run_queue_group)
        self.sim_run_queue_head_line_bottom.setFrameShadow(QtWidgets.QFrame.Plain)
        self.sim_run_queue_head_line_bottom.setLineWidth(0)
        self.sim_run_queue_head_line_bottom.setMidLineWidth(1)
        self.sim_run_queue_head_line_bottom.setFrameShape(QtWidgets.QFrame.HLine)
        self.sim_run_queue_head_line_bottom.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.sim_run_queue_head_line_bottom.setObjectName("sim_run_queue_head_line_bottom")
        self.gridLayout_5.addWidget(self.sim_run_queue_head_line_bottom, 3, 0, 1, 9)
        self.sim_run_queue_sim_status = QtWidgets.QLabel(self.sim_run_queue_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_sim_status.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_sim_status.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_run_queue_sim_status.setFont(font)
        self.sim_run_queue_sim_status.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.sim_run_queue_sim_status.setObjectName("sim_run_queue_sim_status")
        self.gridLayout_5.addWidget(self.sim_run_queue_sim_status, 7, 8, 1, 1)
        self.sim_run_queue_init_status = QtWidgets.QLabel(self.sim_run_queue_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_init_status.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_init_status.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_run_queue_init_status.setFont(font)
        self.sim_run_queue_init_status.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.sim_run_queue_init_status.setObjectName("sim_run_queue_init_status")
        self.gridLayout_5.addWidget(self.sim_run_queue_init_status, 5, 8, 1, 1)
        self.sim_run_queue_seed_status = QtWidgets.QLabel(self.sim_run_queue_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_seed_status.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_seed_status.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_run_queue_seed_status.setFont(font)
        self.sim_run_queue_seed_status.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.sim_run_queue_seed_status.setObjectName("sim_run_queue_seed_status")
        self.gridLayout_5.addWidget(self.sim_run_queue_seed_status, 4, 8, 1, 1)
        self.sim_run_queue_head_line_top = QtWidgets.QFrame(self.sim_run_queue_group)
        self.sim_run_queue_head_line_top.setFrameShadow(QtWidgets.QFrame.Plain)
        self.sim_run_queue_head_line_top.setLineWidth(0)
        self.sim_run_queue_head_line_top.setMidLineWidth(1)
        self.sim_run_queue_head_line_top.setFrameShape(QtWidgets.QFrame.HLine)
        self.sim_run_queue_head_line_top.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.sim_run_queue_head_line_top.setObjectName("sim_run_queue_head_line_top")
        self.gridLayout_5.addWidget(self.sim_run_queue_head_line_top, 0, 0, 1, 9)
        self.sim_run_queue_head_status = QtWidgets.QLabel(self.sim_run_queue_group)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(2)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sim_run_queue_head_status.sizePolicy().hasHeightForWidth())
        self.sim_run_queue_head_status.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.sim_run_queue_head_status.setFont(font)
        self.sim_run_queue_head_status.setObjectName("sim_run_queue_head_status")
        self.gridLayout_5.addWidget(self.sim_run_queue_head_status, 1, 8, 2, 1)
        self.sim_run_queue_seed_export_none = QtWidgets.QWidget(self.sim_run_queue_group)
        self.sim_run_queue_seed_export_none.setObjectName("sim_run_queue_seed_export_none")
        self.horizontalLayout_35 = QtWidgets.QHBoxLayout(self.sim_run_queue_seed_export_none)
        self.horizontalLayout_35.setSpacing(0)
        self.horizontalLayout_35.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_35.setObjectName("horizontalLayout_35")
        self.line_2 = QtWidgets.QFrame(self.sim_run_queue_seed_export_none)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.horizontalLayout_35.addWidget(self.line_2)
        self.label_23 = QtWidgets.QLabel(self.sim_run_queue_seed_export_none)
        self.label_23.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_23.setObjectName("label_23")
        self.horizontalLayout_35.addWidget(self.label_23)
        self.line = QtWidgets.QFrame(self.sim_run_queue_seed_export_none)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout_35.addWidget(self.line)
        self.gridLayout_5.addWidget(self.sim_run_queue_seed_export_none, 4, 6, 1, 1)
        self.line_3 = QtWidgets.QFrame(self.sim_run_queue_group)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_3.setLineWidth(0)
        self.line_3.setMidLineWidth(1)
        self.line_3.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.gridLayout_5.addWidget(self.line_3, 8, 0, 1, 9)
        self.gridLayout_30.addWidget(self.sim_run_queue_group, 2, 0, 1, 1)
        self.sim_cmd_tab_run_area.setWidget(self.sim_cmd_tab_run)
        self.sim_tab.addTab(self.sim_cmd_tab_run_area, "")
        self.gridLayout.addWidget(self.sim_tab, 0, 2, 1, 1)
        main_window.setCentralWidget(self.centralWidget)
        self.menu_bar = QtWidgets.QMenuBar(main_window)
        self.menu_bar.setGeometry(QtCore.QRect(0, 0, 1572, 27))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.menu_bar.sizePolicy().hasHeightForWidth())
        self.menu_bar.setSizePolicy(sizePolicy)
        self.menu_bar.setObjectName("menu_bar")
        self.menu_file = QtWidgets.QMenu(self.menu_bar)
        self.menu_file.setObjectName("menu_file")
        self.menu_help = QtWidgets.QMenu(self.menu_bar)
        self.menu_help.setObjectName("menu_help")
        self.menu_edit = QtWidgets.QMenu(self.menu_bar)
        self.menu_edit.setObjectName("menu_edit")
        main_window.setMenuBar(self.menu_bar)
        self.toolbar = QtWidgets.QToolBar(main_window)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.toolbar.sizePolicy().hasHeightForWidth())
        self.toolbar.setSizePolicy(sizePolicy)
        self.toolbar.setIconSize(QtCore.QSize(16, 16))
        self.toolbar.setObjectName("toolbar")
        main_window.addToolBar(QtCore.Qt.TopToolBarArea, self.toolbar)
        self.status_bar = QtWidgets.QStatusBar(main_window)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.status_bar.sizePolicy().hasHeightForWidth())
        self.status_bar.setSizePolicy(sizePolicy)
        self.status_bar.setObjectName("status_bar")
        main_window.setStatusBar(self.status_bar)
        self.action_open_sim = QtWidgets.QAction(main_window)
        icon19 = QtGui.QIcon()
        icon19.addFile(":/icon/betsee/document_open.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_open_sim.setIcon(icon19)
        self.action_open_sim.setShortcutContext(QtCore.Qt.ApplicationShortcut)
        self.action_open_sim.setMenuRole(QtWidgets.QAction.ApplicationSpecificRole)
        self.action_open_sim.setObjectName("action_open_sim")
        self.action_exit = QtWidgets.QAction(main_window)
        self.action_exit.setShortcutContext(QtCore.Qt.ApplicationShortcut)
        self.action_exit.setMenuRole(QtWidgets.QAction.QuitRole)
        self.action_exit.setObjectName("action_exit")
        self.action_save_sim = QtWidgets.QAction(main_window)
        icon20 = QtGui.QIcon()
        icon20.addFile(":/icon/open_iconic/document.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_save_sim.setIcon(icon20)
        self.action_save_sim.setMenuRole(QtWidgets.QAction.ApplicationSpecificRole)
        self.action_save_sim.setObjectName("action_save_sim")
        self.action_about_betsee = QtWidgets.QAction(main_window)
        self.action_about_betsee.setMenuRole(QtWidgets.QAction.AboutRole)
        self.action_about_betsee.setObjectName("action_about_betsee")
        self.action_edit_prefs = QtWidgets.QAction(main_window)
        icon21 = QtGui.QIcon()
        icon21.addFile(":/icon/open_iconic/wrench.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_edit_prefs.setIcon(icon21)
        self.action_edit_prefs.setMenuRole(QtWidgets.QAction.ApplicationSpecificRole)
        self.action_edit_prefs.setObjectName("action_edit_prefs")
        self.action_make_sim = QtWidgets.QAction(main_window)
        icon22 = QtGui.QIcon()
        icon22.addFile(":/icon/open_iconic/file.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_make_sim.setIcon(icon22)
        self.action_make_sim.setMenuRole(QtWidgets.QAction.ApplicationSpecificRole)
        self.action_make_sim.setObjectName("action_make_sim")
        self.action_about_betse = QtWidgets.QAction(main_window)
        self.action_about_betse.setObjectName("action_about_betse")
        self.action_save_sim_as = QtWidgets.QAction(main_window)
        self.action_save_sim_as.setObjectName("action_save_sim_as")
        self.action_cut = QtWidgets.QAction(main_window)
        icon23 = QtGui.QIcon()
        icon23.addFile(":/icon/entypo+/scissors.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_cut.setIcon(icon23)
        self.action_cut.setObjectName("action_cut")
        self.action_copy = QtWidgets.QAction(main_window)
        icon24 = QtGui.QIcon()
        icon24.addFile(":/icon/entypo+/copy.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_copy.setIcon(icon24)
        self.action_copy.setObjectName("action_copy")
        self.action_paste = QtWidgets.QAction(main_window)
        icon25 = QtGui.QIcon()
        icon25.addFile(":/icon/entypo+/clipboard.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_paste.setIcon(icon25)
        self.action_paste.setObjectName("action_paste")
        self.action_close_sim = QtWidgets.QAction(main_window)
        icon26 = QtGui.QIcon()
        icon26.addFile(":/icon/open_iconic/x.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_close_sim.setIcon(icon26)
        self.action_close_sim.setObjectName("action_close_sim")
        self.action_sim_conf_tree_item_append = QtWidgets.QAction(main_window)
        icon27 = QtGui.QIcon()
        icon27.addFile(":/icon/open_iconic/plus.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_sim_conf_tree_item_append.setIcon(icon27)
        self.action_sim_conf_tree_item_append.setObjectName("action_sim_conf_tree_item_append")
        self.action_sim_conf_tree_item_remove = QtWidgets.QAction(main_window)
        icon28 = QtGui.QIcon()
        icon28.addFile(":/icon/open_iconic/minus.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_sim_conf_tree_item_remove.setIcon(icon28)
        self.action_sim_conf_tree_item_remove.setObjectName("action_sim_conf_tree_item_remove")
        self.action_sim_run_stop_work = QtWidgets.QAction(main_window)
        icon29 = QtGui.QIcon()
        icon29.addFile(":/icon/open_iconic/media-stop.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_sim_run_stop_work.setIcon(icon29)
        self.action_sim_run_stop_work.setObjectName("action_sim_run_stop_work")
        self.action_sim_run_toggle_work = QtWidgets.QAction(main_window)
        self.action_sim_run_toggle_work.setCheckable(True)
        icon30 = QtGui.QIcon()
        icon30.addFile(":/icon/open_iconic/media-play.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon30.addFile(":/icon/open_iconic/media-pause.svg", QtCore.QSize(), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.action_sim_run_toggle_work.setIcon(icon30)
        self.action_sim_run_toggle_work.setObjectName("action_sim_run_toggle_work")
        self.sim_conf_tree_toolbar.addAction(self.action_sim_conf_tree_item_append)
        self.sim_conf_tree_toolbar.addAction(self.action_sim_conf_tree_item_remove)
        self.sim_run_player_toolbar .addAction(self.action_sim_run_toggle_work)
        self.sim_run_player_toolbar .addAction(self.action_sim_run_stop_work)
        self.menu_file.addAction(self.action_make_sim)
        self.menu_file.addAction(self.action_open_sim)
        self.menu_file.addAction(self.action_close_sim)
        self.menu_file.addSeparator()
        self.menu_file.addAction(self.action_save_sim)
        self.menu_file.addAction(self.action_save_sim_as)
        self.menu_file.addSeparator()
        self.menu_file.addAction(self.action_exit)
        self.menu_help.addAction(self.action_about_betse)
        self.menu_help.addAction(self.action_about_betsee)
        self.menu_edit.addSeparator()
        self.menu_edit.addAction(self.action_cut)
        self.menu_edit.addAction(self.action_copy)
        self.menu_edit.addAction(self.action_paste)
        self.menu_edit.addSeparator()
        self.menu_edit.addAction(self.action_edit_prefs)
        self.menu_bar.addAction(self.menu_file.menuAction())
        self.menu_bar.addAction(self.menu_edit.menuAction())
        self.menu_bar.addAction(self.menu_help.menuAction())
        self.toolbar.addAction(self.action_make_sim)
        self.toolbar.addAction(self.action_open_sim)
        self.toolbar.addAction(self.action_save_sim)
        self.toolbar.addAction(self.action_close_sim)
        self.toolbar.addSeparator()
        self.toolbar.addAction(self.action_cut)
        self.toolbar.addAction(self.action_copy)
        self.toolbar.addAction(self.action_paste)
        self.toolbar.addSeparator()

        self.retranslateUi(main_window)
        self.sim_conf_stack.setCurrentIndex(4)
        QtCore.QMetaObject.connectSlotsByName(main_window)

    def retranslateUi(self, main_window):
        self.sim_conf_tree.headerItem().setText(0, QtWidgets.QApplication.translate("main_window", "Configuration", None, -1))
        __sortingEnabled = self.sim_conf_tree.isSortingEnabled()
        self.sim_conf_tree.setSortingEnabled(False)
        self.sim_conf_tree.topLevelItem(0).setText(0, QtWidgets.QApplication.translate("main_window", "Space", None, -1))
        self.sim_conf_tree.topLevelItem(0).child(0).setText(0, QtWidgets.QApplication.translate("main_window", "Tissue", None, -1))
        self.sim_conf_tree.topLevelItem(1).setText(0, QtWidgets.QApplication.translate("main_window", "Time", None, -1))
        self.sim_conf_tree.topLevelItem(2).setText(0, QtWidgets.QApplication.translate("main_window", "Ions", None, -1))
        self.sim_conf_tree.topLevelItem(3).setText(0, QtWidgets.QApplication.translate("main_window", "Paths", None, -1))
        self.sim_conf_tree.topLevelItem(4).setText(0, QtWidgets.QApplication.translate("main_window", "--[TODO]--", None, -1))
        self.sim_conf_tree.topLevelItem(5).setText(0, QtWidgets.QApplication.translate("main_window", "Dynamic Channels", None, -1))
        self.sim_conf_tree.topLevelItem(6).setText(0, QtWidgets.QApplication.translate("main_window", "Interventions", None, -1))
        self.sim_conf_tree.topLevelItem(7).setText(0, QtWidgets.QApplication.translate("main_window", "Junctions", None, -1))
        self.sim_conf_tree.topLevelItem(8).setText(0, QtWidgets.QApplication.translate("main_window", "Network", None, -1))
        self.sim_conf_tree.topLevelItem(8).child(0).setText(0, QtWidgets.QApplication.translate("main_window", "Substances", None, -1))
        self.sim_conf_tree.topLevelItem(8).child(1).setText(0, QtWidgets.QApplication.translate("main_window", "Reactions", None, -1))
        self.sim_conf_tree.topLevelItem(8).child(2).setText(0, QtWidgets.QApplication.translate("main_window", "Transporters", None, -1))
        self.sim_conf_tree.topLevelItem(8).child(3).setText(0, QtWidgets.QApplication.translate("main_window", "Channels", None, -1))
        self.sim_conf_tree.topLevelItem(8).child(4).setText(0, QtWidgets.QApplication.translate("main_window", "Modulators", None, -1))
        self.sim_conf_tree.topLevelItem(9).setText(0, QtWidgets.QApplication.translate("main_window", "Additional Physics", None, -1))
        self.sim_conf_tree.topLevelItem(10).setText(0, QtWidgets.QApplication.translate("main_window", "Tools", None, -1))
        self.sim_conf_tree.topLevelItem(11).setText(0, QtWidgets.QApplication.translate("main_window", "Advanced", None, -1))
        self.sim_conf_tree.topLevelItem(12).setText(0, QtWidgets.QApplication.translate("main_window", "Results", None, -1))
        self.sim_conf_tree.topLevelItem(13).setText(0, QtWidgets.QApplication.translate("main_window", "Data Export", None, -1))
        self.sim_conf_tree.topLevelItem(14).setText(0, QtWidgets.QApplication.translate("main_window", "Line Plots", None, -1))
        self.sim_conf_tree.topLevelItem(15).setText(0, QtWidgets.QApplication.translate("main_window", "2D Plots", None, -1))
        self.sim_conf_tree.topLevelItem(16).setText(0, QtWidgets.QApplication.translate("main_window", "Animations", None, -1))
        self.sim_conf_tree.setSortingEnabled(__sortingEnabled)
        self.log_label.setText(QtWidgets.QApplication.translate("main_window", "Log Messages", None, -1))
        self.groupBox_50.setTitle(QtWidgets.QApplication.translate("main_window", "Path Settings", None, -1))
        self.groupBox_13.setToolTip(QtWidgets.QApplication.translate("main_window", "Paths produced by this simulation\'s seed phase.", None, -1))
        self.groupBox_13.setTitle(QtWidgets.QApplication.translate("main_window", "Seed Phase", None, -1))
        self.label_2.setText(QtWidgets.QApplication.translate("main_window", "Pickle basename:", None, -1))
        self.sim_conf_path_seed_pick_file_line.setToolTip(QtWidgets.QApplication.translate("main_window", "Basename of the pickled file providing this simulation\'s most recently seeded cell cluster in the initialization pickle directory.", None, -1))
        self.groupBox_11.setToolTip(QtWidgets.QApplication.translate("main_window", "Paths produced by this simulation\'s initialization phase.", None, -1))
        self.groupBox_11.setTitle(QtWidgets.QApplication.translate("main_window", "Initialization Phase", None, -1))
        self.label.setText(QtWidgets.QApplication.translate("main_window", "Pickle dirname:", None, -1))
        self.widget_5.setToolTip(QtWidgets.QApplication.translate("main_window", "Relative pathname of the directory containing files pickled by the most recent seed and initialization runs of this simulation.", None, -1))
        self.sim_conf_path_init_pick_dir_btn.setToolTip(QtWidgets.QApplication.translate("main_window", "Interactively browse the filesystem for this directory.", None, -1))
        self.sim_conf_path_init_pick_dir_btn.setText(QtWidgets.QApplication.translate("main_window", "Browse...", None, -1))
        self.label_4.setText(QtWidgets.QApplication.translate("main_window", "Pickle basename:", None, -1))
        self.sim_conf_path_init_pick_file_line.setToolTip(QtWidgets.QApplication.translate("main_window", "Basename of the pickled file providing this simulation\'s most recent initialization run in this directory.", None, -1))
        self.label_3.setText(QtWidgets.QApplication.translate("main_window", "Exports dirname:", None, -1))
        self.widget_6.setToolTip(QtWidgets.QApplication.translate("main_window", "Relative pathname of the directory containing results exported by the most recent seed and initialization runs of this simulation.", None, -1))
        self.sim_conf_path_init_exp_dir_btn.setToolTip(QtWidgets.QApplication.translate("main_window", "Interactively browse the filesystem for this directory.", None, -1))
        self.sim_conf_path_init_exp_dir_btn.setText(QtWidgets.QApplication.translate("main_window", "Browse...", None, -1))
        self.groupBox_12.setToolTip(QtWidgets.QApplication.translate("main_window", "Paths produced by this simulation\'s simulation phase.", None, -1))
        self.groupBox_12.setTitle(QtWidgets.QApplication.translate("main_window", "Simulation Phase", None, -1))
        self.label_5.setText(QtWidgets.QApplication.translate("main_window", "Pickle dirname:", None, -1))
        self.widget_7.setToolTip(QtWidgets.QApplication.translate("main_window", "Relative pathname of the directory containing files pickled by the most recent simulation run of this simulation.", None, -1))
        self.sim_conf_path_sim_pick_dir_btn.setToolTip(QtWidgets.QApplication.translate("main_window", "Interactively browse the filesystem for this directory.", None, -1))
        self.sim_conf_path_sim_pick_dir_btn.setText(QtWidgets.QApplication.translate("main_window", "Browse...", None, -1))
        self.label_62.setText(QtWidgets.QApplication.translate("main_window", "Pickle basename:", None, -1))
        self.sim_conf_path_sim_pick_file_line.setToolTip(QtWidgets.QApplication.translate("main_window", "Basename of the pickled file providing this simulation\'s most recent simulation run in this directory.", None, -1))
        self.label_73.setText(QtWidgets.QApplication.translate("main_window", "Exports dirname:", None, -1))
        self.widget_8.setToolTip(QtWidgets.QApplication.translate("main_window", "Relative pathname of the directory containing results exported by the most recent simulation run of this simulation.", None, -1))
        self.sim_conf_path_sim_exp_dir_btn.setToolTip(QtWidgets.QApplication.translate("main_window", "Interactively browse the filesystem for this directory.", None, -1))
        self.sim_conf_path_sim_exp_dir_btn.setText(QtWidgets.QApplication.translate("main_window", "Browse...", None, -1))
        self.groupBox_51.setTitle(QtWidgets.QApplication.translate("main_window", "Temporal Settings", None, -1))
        self.groupBox_14.setToolTip(QtWidgets.QApplication.translate("main_window", "Time-related properties of this simulation\'s initialization phase.", None, -1))
        self.groupBox_14.setTitle(QtWidgets.QApplication.translate("main_window", "Initialization Phase", None, -1))
        self.label_77.setText(QtWidgets.QApplication.translate("main_window", "Total time:", None, -1))
        self.widget_9.setToolTip(QtWidgets.QApplication.translate("main_window", "Duration in seconds [s] of this simulation\'s initialization phase.", None, -1))
        self.label_6.setText(QtWidgets.QApplication.translate("main_window", "seconds", None, -1))
        self.label_75.setText(QtWidgets.QApplication.translate("main_window", "Time step:", None, -1))
        self.widget_10.setToolTip(QtWidgets.QApplication.translate("main_window", "Duration in seconds [s] of each time step (both sampled and unsampled) of this simulation\'s initialization phase.", None, -1))
        self.label_7.setText(QtWidgets.QApplication.translate("main_window", "seconds", None, -1))
        self.label_76.setText(QtWidgets.QApplication.translate("main_window", "Sampling rate:", None, -1))
        self.widget_11.setToolTip(QtWidgets.QApplication.translate("main_window", "Duration in seconds [s] between each sampled time step (inclusive) of this simulation\'s initialization phase. Decreasing this duration increases the number of time steps for which data is exported from this phase at a linear cost in space consumption.", None, -1))
        self.label_8.setText(QtWidgets.QApplication.translate("main_window", "seconds", None, -1))
        self.groupBox_15.setToolTip(QtWidgets.QApplication.translate("main_window", "Time-related properties of this simulation\'s simulation phase.", None, -1))
        self.groupBox_15.setTitle(QtWidgets.QApplication.translate("main_window", "Simulation Phase", None, -1))
        self.label_78.setText(QtWidgets.QApplication.translate("main_window", "Total time:", None, -1))
        self.widget_12.setToolTip(QtWidgets.QApplication.translate("main_window", "Duration in seconds [s] of this simulation\'s simulation phase.", None, -1))
        self.label_9.setText(QtWidgets.QApplication.translate("main_window", "seconds", None, -1))
        self.label_79.setText(QtWidgets.QApplication.translate("main_window", "Time step:", None, -1))
        self.widget_13.setToolTip(QtWidgets.QApplication.translate("main_window", "Duration in seconds [s] of each time step (both sampled and unsampled) of this simulation\'s simulation phase.", None, -1))
        self.label_10.setText(QtWidgets.QApplication.translate("main_window", "seconds", None, -1))
        self.label_80.setText(QtWidgets.QApplication.translate("main_window", "Sampling rate:", None, -1))
        self.widget_14.setToolTip(QtWidgets.QApplication.translate("main_window", "Duration in seconds [s] between each sampled time step (inclusive) of this simulation\'s simulation phase. Decreasing this duration increases the number of time steps for which data is exported from this phase at a linear cost in space consumption.", None, -1))
        self.label_11.setText(QtWidgets.QApplication.translate("main_window", "seconds", None, -1))
        self.groupBox_52.setTitle(QtWidgets.QApplication.translate("main_window", "Ions", None, -1))
        self.groupBox_20.setToolTip(QtWidgets.QApplication.translate("main_window", "Predefined ion profiles enabling ions in typical combinations at typical initial concentrations.", None, -1))
        self.groupBox_20.setTitle(QtWidgets.QApplication.translate("main_window", "Preset", None, -1))
        self.label_14.setText(QtWidgets.QApplication.translate("main_window", "Ion profile:", None, -1))
        self.sim_conf_ion_profile.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"Type of ion profile (i.e., predefined set of all extracellular and cytosolic\n"
"ions enabled by this simulation), such that:\n"
"</p><ul><li>\n"
"<b>Basic</b> enables M<sup><b>-</b></sup> (charge-balance),\n"
"Na<sup><b>+</b></sup> (sodium), K<sup><b>+</b></sup> (potassium), and\n"
"proteins<sup><b>-</b></sup> ions. This profile is the proper subset of all other\n"
"predefined ion profiles.\n"
"</li><li>\n"
"<b>Basic + Ca<sup>2+</sup></b> enables M<sup><b>-</b></sup>\n"
"(charge-balance), Na<sup><b>+</b></sup> (sodium), K<sup><b>+</b></sup>\n"
"(potassium), proteins<sup><b>-</b></sup>, and Ca<sup>2<b>+</b></sup> ions. This\n"
"profile is the superset of the <b>Basic</b> profile enabling\n"
"Ca<sup>2<b>+</b></sup> ions.\n"
"</li><li>\n"
"<b>Mammal</b> enables M<sup><b>-</b></sup> (charge-balance),\n"
"Na<sup><b>+</b></sup> (sodium), K<sup><b>+</b></sup> (potassium),\n"
"proteins<sup><b>-</b></sup>, Ca<sup>2<b>+</b></sup>, Cl<sup><b>-</b></sup>\n"
"(chloride), and H<sup><b>+</b></sup> (hydrogen) ions expressed in amniotic\n"
"environmental concentrations, principally intended for mammalian cell clusters.\n"
"This profile is the superset of the <b>Basic + Ca<sup>2+</sup></b> profile\n"
"enabling Cl<sup><b>-</b></sup> and H<sup><b>+</b></sup> ions.\n"
"</li><li>\n"
"<b>Amphibian</b> enables M<sup><b>-</b></sup> (charge-balance),\n"
"Na<sup><b>+</b></sup> (sodium), K<sup><b>+</b></sup> (potassium),\n"
"proteins<sup><b>-</b></sup>, Ca<sup>2<b>+</b></sup>, Cl<sup><b>-</b></sup>\n"
"(chloride), and H<sup><b>+</b></sup> (hydrogen) ions expressed in aquatic\n"
"environmental concentrations, principally intended for amphibian cell clusters.\n"
"This profile enables the same ions as the <b>Mammal</b> profile – albeit in\n"
"differing concentrations.\n"
"</li><li>\n"
"<b>Custom</b> creates a user-defined ion profile enabling all extracellular and\n"
"cytosolic ions in the concentrations specified below.\n"
"</li></ul><p>\n"
"All ion profiles contain an unidentified charge-balance anion denoted\n"
"M<sup><b>-</b></sup>, as required for both simulation stability and correctness. \n"
"</p></body></html>", None, -1))
        self.sim_conf_ion_custom.setToolTip(QtWidgets.QApplication.translate("main_window", "User-defined ion profile explicitly specifying the initial extracellular and cystolic concentrations of all ions at the first simulation time step.", None, -1))
        self.sim_conf_ion_custom.setTitle(QtWidgets.QApplication.translate("main_window", "Custom", None, -1))
        self.groupBox_18.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"Initial extracellular concentrations of all ions at the first simulation time step. Note that these concentrations should ideally sum to zero charge by treating:</p><ul>\n"
"<li>\n"
"Cations as positive charges of magnitude equal to their concentrations.\n"
"</li><li>\n"
"Anions as negative charges of magnitude equal to their concentrations.\n"
"</ul></body></html>", None, -1))
        self.groupBox_18.setTitle(QtWidgets.QApplication.translate("main_window", "Extracellular Concentrations", None, -1))
        self.label_84.setText(QtWidgets.QApplication.translate("main_window", "Na<sup><b>+</b></sup>:", None, -1))
        self.widget_18.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"Initial extracellular concentration of the Na<sup><b>+</b></sup> (sodium) cation at the first simulation time step.\n"
"</p></body></html>", None, -1))
        self.label_85.setText(QtWidgets.QApplication.translate("main_window", "mmol/L", None, -1))
        self.label_86.setText(QtWidgets.QApplication.translate("main_window", "K<sup><b>+</b></sup>:", None, -1))
        self.widget_19.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"Initial extracellular concentration of the K<sup><b>+</b></sup> (potassium) cation at the first simulation time step.\n"
"</p></body></html>", None, -1))
        self.label_87.setText(QtWidgets.QApplication.translate("main_window", "mmol/L", None, -1))
        self.label_88.setText(QtWidgets.QApplication.translate("main_window", "Cl<sup><b>-</b></sup>:", None, -1))
        self.widget_20.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"Initial extracellular concentration of the Cl<sup><b>-</b></sup> (chloride) anion at the first simulation time step.\n"
"</p></body></html>", None, -1))
        self.label_89.setText(QtWidgets.QApplication.translate("main_window", "mmol/L", None, -1))
        self.widget_21.setToolTip(QtWidgets.QApplication.translate("main_window", "Duration in seconds of this simulation\'s simulation phase.", None, -1))
        self.widget_22.setToolTip(QtWidgets.QApplication.translate("main_window", "Duration in seconds of each time step (both sampled and unsampled) of this simulation\'s simulation phase.", None, -1))
        self.widget_23.setToolTip(QtWidgets.QApplication.translate("main_window", "Duration in seconds between each sampled time step (inclusive) of this simulation\'s simulation phase. Decreasing this duration increases the number of time steps for which data is exported from this phase at a linear cost in space consumption.", None, -1))
        self.groupBox_53.setTitle(QtWidgets.QApplication.translate("main_window", "Spatial Settings", None, -1))
        self.groupBox_17.setToolTip(QtWidgets.QApplication.translate("main_window", "Space-related properties of this simulation\'s cell cluster.", None, -1))
        self.groupBox_17.setTitle(QtWidgets.QApplication.translate("main_window", "Cell Cluster", None, -1))
        self.label_18.setText(QtWidgets.QApplication.translate("main_window", "Cell radius:", None, -1))
        self.widget_17.setToolTip(QtWidgets.QApplication.translate("main_window", "Radius in meters [m] of each cell in this cluster. This should typically be within an order of magnitude of the recommended default of 5.0e-6.", None, -1))
        self.label_83.setText(QtWidgets.QApplication.translate("main_window", "meters", None, -1))
        self.label_81.setToolTip(QtWidgets.QApplication.translate("main_window", "Type of base cell lattice (i.e., uniform grid to which cells are situated before random lattice disorder is applied).", None, -1))
        self.label_81.setText(QtWidgets.QApplication.translate("main_window", "Lattice type:", None, -1))
        self.label_20.setText(QtWidgets.QApplication.translate("main_window", "Lattice disorder:", None, -1))
        self.widget_25.setToolTip(QtWidgets.QApplication.translate("main_window", "Degree to which cell boundaries spatially deviate from the base cell lattice. If 0.0, cells rigidly conform to this lattice; else, cells randomly deviate from this lattice. Increasing this increases the entropy (i.e., randomness) of these deviations, producing an increasingly chaotic arrangement of cells. This should typically reside in the range [0.0, 0.8].", None, -1))
        self.label_90.setText(QtWidgets.QApplication.translate("main_window", "/ 1.00", None, -1))
        self.widget_3.setToolTip(QtWidgets.QApplication.translate("main_window", "Type of base cell lattice (i.e., uniform grid to which cells are situated before random lattice disorder is applied).", None, -1))
        self.sim_conf_space_intra_lattice_hex.setToolTip(QtWidgets.QApplication.translate("main_window", "Situate cells along a hexagonal grid.", None, -1))
        self.sim_conf_space_intra_lattice_hex.setText(QtWidgets.QApplication.translate("main_window", "He&xagonal", None, -1))
        self.sim_conf_space_intra_lattice_square.setToolTip(QtWidgets.QApplication.translate("main_window", "Situate cells along a square grid.", None, -1))
        self.sim_conf_space_intra_lattice_square.setText(QtWidgets.QApplication.translate("main_window", "S&quare", None, -1))
        self.groupBox_16.setToolTip(QtWidgets.QApplication.translate("main_window", "Space-related properties of this simulation\'s extracellular environment.", None, -1))
        self.groupBox_16.setTitle(QtWidgets.QApplication.translate("main_window", "Environment", None, -1))
        self.label_17.setText(QtWidgets.QApplication.translate("main_window", "World length:", None, -1))
        self.widget_15.setToolTip(QtWidgets.QApplication.translate("main_window", "Length in meters [m] of both the X and Y dimensions of this simulation\'s square environment. This should typically be in the range [80e-6, 1000e-6].", None, -1))
        self.label_19.setText(QtWidgets.QApplication.translate("main_window", "meters", None, -1))
        self.label_74.setText(QtWidgets.QApplication.translate("main_window", "World grid size:", None, -1))
        self.widget_16.setToolTip(QtWidgets.QApplication.translate("main_window", "Number of square grid spaces (in both the X and Y dimensions) to computationally divide this simulation\'s square environment into. Increasing this increases simulation granularity and hence stability at a quadratic increase in space and time costs. This should typically be in the range [10, 60].", None, -1))
        self.label_82.setText(QtWidgets.QApplication.translate("main_window", "squares", None, -1))
        self.label_12.setText(QtWidgets.QApplication.translate("main_window", "Extracellular matrix:", None, -1))
        self.sim_conf_space_extra_is_ecm.setToolTip(QtWidgets.QApplication.translate("main_window", "Enable the extracellular matrix (ECM), simulating the environmental spaces surrounding each cell in the cluster? Disabling this substantially reduces simulation accuracy at a substantial reduction in space and time costs.", None, -1))
        self.groupBox_23.setToolTip(QtWidgets.QApplication.translate("main_window", "Default tissue profile for all unselected cells (i.e., cells not already selected by a tissue profile listed to the left).", None, -1))
        self.groupBox_23.setTitle(QtWidgets.QApplication.translate("main_window", "Default Tissue Profile", None, -1))
        self.groupBox_22.setToolTip(QtWidgets.QApplication.translate("main_window", "General-purpose properties of the default tissue profile.", None, -1))
        self.groupBox_22.setTitle(QtWidgets.QApplication.translate("main_window", "Tissue Properties", None, -1))
        self.label_16.setText(QtWidgets.QApplication.translate("main_window", "Name:", None, -1))
        self.sim_conf_tis_default_name.setToolTip(QtWidgets.QApplication.translate("main_window", "Arbitrary string uniquely identifying the default tissue profile. This name must be unique to this profile (i.e., not shared with any other tissue profile).", None, -1))
        self.groupBox_21.setToolTip(QtWidgets.QApplication.translate("main_window", "Exterior shape of the entire cell cluster.", None, -1))
        self.groupBox_21.setTitle(QtWidgets.QApplication.translate("main_window", "Cell Cluster Shape", None, -1))
        self.label_91.setText(QtWidgets.QApplication.translate("main_window", "Image mask:", None, -1))
        self.widget_26.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"Absolute or relative filename of the image mask whose pure-black pixels (i.e., pixels whose red, green, and blue color components are all 0) define the exterior shape of the entire cell cluster. This image <i>must</i>:\n"
"<ul>\n"
"<li>Be square (i.e., have equal pixel dimensions).</li>\n"
"<li>Contain no alpha transparency layer.</li>\n"
"</ul>\n"
"To avoid rescaling issues, all such images <i>should</i> also:\n"
"<ul>\n"
"<li>Be of the same filetype.</li>\n"
"<li>Have the same dimensions.</li>\n"
"</ul>\n"
"</p></body></html>", None, -1))
        self.sim_conf_tis_default_image_btn.setToolTip(QtWidgets.QApplication.translate("main_window", "Interactively browse the filesystem for this file.", None, -1))
        self.sim_conf_tis_default_image_btn.setText(QtWidgets.QApplication.translate("main_window", "Browse...", None, -1))
        self.groupBox_24.setToolTip(QtWidgets.QApplication.translate("main_window", "Default membrane diffusion constants for all unselected cells (i.e., cells not already selected by a tissue profile listed to the left).", None, -1))
        self.groupBox_24.setTitle(QtWidgets.QApplication.translate("main_window", "Membrane Diffusion Constants", None, -1))
        self.label_54.setText(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"Sodium (<i>Na<sup>+</sup></i>):\n"
"</p></body></html>", None, -1))
        self.widget_27.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"Rate in meters squared per second [m<sup>2</sup>/s] at which sodium cations (<i>Na<sup>+</sup></i>) diffuse across the membranes of unselected cells.\n"
"</p></body></html>", None, -1))
        self.label_92.setText(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"m<sup>2</sup>/s\n"
"</p></body></html>", None, -1))
        self.label_55.setText(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"Potassium (<i>K<sup>+</sup></i>):\n"
"</p></body></html>", None, -1))
        self.widget_28.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"Rate in meters squared per second [m<sup>2</sup>/s] at which potassium cations (<i>K<sup>+</sup></i>) diffuse across the membranes of unselected cells.\n"
"</p></body></html>", None, -1))
        self.label_93.setText(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"m<sup>2</sup>/s\n"
"</p></body></html>", None, -1))
        self.label_56.setText(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"Chloride (<i>Cl<sup>-</sup></i>):\n"
"</p></body></html>", None, -1))
        self.widget_29.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"Rate in meters squared per second [m<sup>2</sup>/s] at which chloride anions (<i>Cl<sup>-</sup></i>) diffuse across the membranes of unselected cells.\n"
"</p></body></html>", None, -1))
        self.label_94.setText(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"m<sup>2</sup>/s\n"
"</p></body></html>", None, -1))
        self.label_57.setText(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"Calcium (<i>Ca<sup>2+</sup></i>):\n"
"</p></body></html>", None, -1))
        self.widget_30.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"Rate in meters squared per second [m<sup>2</sup>/s] at which calcium cations (<i>Ca<sup>2+</sup></i>) diffuse across the membranes of unselected cells.\n"
"</p></body></html>", None, -1))
        self.label_95.setText(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"m<sup>2</sup>/s\n"
"</p></body></html>", None, -1))
        self.label_59.setText(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"Charge balance (<i>M<sup>-</sup></i>):\n"
"</p></body></html>", None, -1))
        self.widget_32.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"Rate in meters squared per second [m<sup>2</sup>/s] at which charge balance anions (<i>M<sup>-</sup></i>) diffuse across the membranes of unselected cells. Charge balance anions are unidentified anions  dynamically fabricated by the simulator as necessary to preserve charge neutrality of the world as a whole.\n"
"</p></body></html>", None, -1))
        self.label_97.setText(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"m<sup>2</sup>/s\n"
"</p></body></html>", None, -1))
        self.label_60.setText(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"Protein (<i>P<sup>-</sup></i>):\n"
"</p></body></html>", None, -1))
        self.widget_33.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"Rate in meters squared per second [m<sup>2</sup>/s] at which protein anions (<i>P<sup>-</sup></i>) diffuse across the membranes of unselected cells.\n"
"</p></body></html>", None, -1))
        self.label_98.setText(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>\n"
"m<sup>2</sup>/s\n"
"</p></body></html>", None, -1))
        self.groupBox_DynamicChannels.setTitle(QtWidgets.QApplication.translate("main_window", "Dynamic Channels", None, -1))
        self.radioButton.setText(QtWidgets.QApplication.translate("main_window", "Turn On", None, -1))
        self.label_15.setText(QtWidgets.QApplication.translate("main_window", "Channel Class:", None, -1))
        self.label_41.setText(QtWidgets.QApplication.translate("main_window", "Channel:", None, -1))
        self.label_42.setText(QtWidgets.QApplication.translate("main_window", "Apply to tissue profile:", None, -1))
        self.label_43.setText(QtWidgets.QApplication.translate("main_window", "Max Value:", None, -1))
        self.groupBox_Interventions.setTitle(QtWidgets.QApplication.translate("main_window", "Interventions", None, -1))
        self.rb_interventionOn.setText(QtWidgets.QApplication.translate("main_window", "Turn On", None, -1))
        self.label_44.setText(QtWidgets.QApplication.translate("main_window", "Type:", None, -1))
        self.label_45.setText(QtWidgets.QApplication.translate("main_window", "Start:", None, -1))
        self.label_46.setText(QtWidgets.QApplication.translate("main_window", "Stop:", None, -1))
        self.label_47.setText(QtWidgets.QApplication.translate("main_window", "Rate:", None, -1))
        self.label_48.setText(QtWidgets.QApplication.translate("main_window", "Multiplier:", None, -1))
        self.label_49.setText(QtWidgets.QApplication.translate("main_window", "Modulator function:", None, -1))
        self.label_50.setText(QtWidgets.QApplication.translate("main_window", "Apply to tissue profile:", None, -1))
        self.comboBox_interventionFunk.setItemText(0, QtWidgets.QApplication.translate("main_window", "None", None, -1))
        self.comboBox_interventionFunk.setItemText(1, QtWidgets.QApplication.translate("main_window", "gradient_x", None, -1))
        self.comboBox_interventionFunk.setItemText(2, QtWidgets.QApplication.translate("main_window", "gradient_y", None, -1))
        self.comboBox_interventionFunk.setItemText(3, QtWidgets.QApplication.translate("main_window", "gradient_r", None, -1))
        self.comboBox_interventionFunk.setItemText(4, QtWidgets.QApplication.translate("main_window", "periodic", None, -1))
        self.comboBox_interventionFunk.setItemText(5, QtWidgets.QApplication.translate("main_window", "f_sweep", None, -1))
        self.groupBox_Junctions.setTitle(QtWidgets.QApplication.translate("main_window", "Junctions", None, -1))
        self.rb_vsGJ.setText(QtWidgets.QApplication.translate("main_window", "&Voltage sensitive GJ", None, -1))
        self.label_25.setText(QtWidgets.QApplication.translate("main_window", "V threshold:  ", None, -1))
        self.label_26.setText(QtWidgets.QApplication.translate("main_window", "GJ minimum:", None, -1))
        self.label_27.setText(QtWidgets.QApplication.translate("main_window", "TJ scaling:", None, -1))
        self.label_28.setText(QtWidgets.QApplication.translate("main_window", "Adherens scaling:", None, -1))
        self.label_22.setText(QtWidgets.QApplication.translate("main_window", "GJ surface area", None, -1))
        self.groupBox_Network.setTitle(QtWidgets.QApplication.translate("main_window", "Network", None, -1))
        self.rb_useNetwork.setText(QtWidgets.QApplication.translate("main_window", "Use network", None, -1))
        self.radioButton_2.setText(QtWidgets.QApplication.translate("main_window", "Use network from e&xternal config:", None, -1))
        self.label_61.setText(QtWidgets.QApplication.translate("main_window", "External Network type:", None, -1))
        self.comboBox_netType.setItemText(0, QtWidgets.QApplication.translate("main_window", "Standard", None, -1))
        self.comboBox_netType.setItemText(1, QtWidgets.QApplication.translate("main_window", "Metabolic", None, -1))
        self.label_21.setText(QtWidgets.QApplication.translate("main_window", "External Network Configuration File:", None, -1))
        self.pushButton_netBrowse.setText(QtWidgets.QApplication.translate("main_window", "Browse", None, -1))
        self.groupBox_AdditionalPhysics.setTitle(QtWidgets.QApplication.translate("main_window", "Additional Physics", None, -1))
        self.rb_eosmoPC.setText(QtWidgets.QApplication.translate("main_window", "Electrophoresis pumps/channels", None, -1))
        self.rb_flow.setText(QtWidgets.QApplication.translate("main_window", "Electroosmotic fluid flow", None, -1))
        self.rb_deform.setText(QtWidgets.QApplication.translate("main_window", "Deformation", None, -1))
        self.rb_osmosis.setText(QtWidgets.QApplication.translate("main_window", "Osmotic pressure", None, -1))
        self.rb_dynNoise.setText(QtWidgets.QApplication.translate("main_window", "Dynamic noise", None, -1))
        self.label_24.setText(QtWidgets.QApplication.translate("main_window", "Static noise level", None, -1))
        self.groupBox_Tools.setTitle(QtWidgets.QApplication.translate("main_window", "Tools and Functions", None, -1))
        self.rb_Goldman.setText(QtWidgets.QApplication.translate("main_window", "Goldman Calculator", None, -1))
        self.groupBox_2.setTitle(QtWidgets.QApplication.translate("main_window", "Advanced Settings", None, -1))
        self.label_29.setText(QtWidgets.QApplication.translate("main_window", "Na/K-ATPase max rate:", None, -1))
        self.label_32.setText(QtWidgets.QApplication.translate("main_window", "Ca-ATPase max rate:", None, -1))
        self.label_33.setText(QtWidgets.QApplication.translate("main_window", "Gaussian smoothing level:", None, -1))
        self.rb_smoothConcs.setText(QtWidgets.QApplication.translate("main_window", "smooth concentrations", None, -1))
        self.rb_subsVmem.setText(QtWidgets.QApplication.translate("main_window", "network substances affect &Vmem", None, -1))
        self.label_40.setText(QtWidgets.QApplication.translate("main_window", "Time acceleration factor:", None, -1))
        self.groupBox_resultsSettings.setTitle(QtWidgets.QApplication.translate("main_window", "Results Settings", None, -1))
        self.rb_autosavePlots.setText(QtWidgets.QApplication.translate("main_window", "Autosave plots and animations", None, -1))
        self.rb_enableAni.setText(QtWidgets.QApplication.translate("main_window", "Enable animations", None, -1))
        self.rb_showCells.setText(QtWidgets.QApplication.translate("main_window", "Show cells", None, -1))
        self.rb_enumerateCells.setText(QtWidgets.QApplication.translate("main_window", "Enumerate cells", None, -1))
        self.rb_IOverlay.setText(QtWidgets.QApplication.translate("main_window", "O&verlay current", None, -1))
        self.label_13.setText(QtWidgets.QApplication.translate("main_window", "Plot cell index:", None, -1))
        self.groupBox_5.setTitle(QtWidgets.QApplication.translate("main_window", "Raw Data Export", None, -1))
        self.label_66.setText(QtWidgets.QApplication.translate("main_window", "Export type:", None, -1))
        self.comboBox_4.setItemText(0, QtWidgets.QApplication.translate("main_window", "1D Data summary", None, -1))
        self.comboBox_4.setItemText(1, QtWidgets.QApplication.translate("main_window", "2D Vmem", None, -1))
        self.groupBox.setTitle(QtWidgets.QApplication.translate("main_window", "Line Plot Settings", None, -1))
        self.label_63.setText(QtWidgets.QApplication.translate("main_window", "Plot type:", None, -1))
        self.comboBox.setItemText(0, QtWidgets.QApplication.translate("main_window", "Vmem", None, -1))
        self.comboBox.setItemText(1, QtWidgets.QApplication.translate("main_window", "Jmem", None, -1))
        self.comboBox.setItemText(2, QtWidgets.QApplication.translate("main_window", "Ion", None, -1))
        self.comboBox.setItemText(3, QtWidgets.QApplication.translate("main_window", "Pump rate", None, -1))
        self.label_67.setText(QtWidgets.QApplication.translate("main_window", "Plot cell:", None, -1))
        self.groupBox_3.setTitle(QtWidgets.QApplication.translate("main_window", "2D Plots", None, -1))
        self.label_64.setText(QtWidgets.QApplication.translate("main_window", "Plot type:", None, -1))
        self.comboBox_2.setItemText(0, QtWidgets.QApplication.translate("main_window", "Vmem", None, -1))
        self.comboBox_2.setItemText(1, QtWidgets.QApplication.translate("main_window", "Venv", None, -1))
        self.comboBox_2.setItemText(2, QtWidgets.QApplication.translate("main_window", "GJ State", None, -1))
        self.comboBox_2.setItemText(3, QtWidgets.QApplication.translate("main_window", "Current", None, -1))
        self.comboBox_2.setItemText(4, QtWidgets.QApplication.translate("main_window", "Ion", None, -1))
        self.comboBox_2.setItemText(5, QtWidgets.QApplication.translate("main_window", "Electric Field", None, -1))
        self.comboBox_2.setItemText(6, QtWidgets.QApplication.translate("main_window", "Pump Rate", None, -1))
        self.groupBox_4.setTitle(QtWidgets.QApplication.translate("main_window", "Animations", None, -1))
        self.label_65.setText(QtWidgets.QApplication.translate("main_window", "Animation Type:", None, -1))
        self.comboBox_3.setItemText(0, QtWidgets.QApplication.translate("main_window", "Vmem", None, -1))
        self.comboBox_3.setItemText(1, QtWidgets.QApplication.translate("main_window", "Venv", None, -1))
        self.comboBox_3.setItemText(2, QtWidgets.QApplication.translate("main_window", "GJ State", None, -1))
        self.comboBox_3.setItemText(3, QtWidgets.QApplication.translate("main_window", "Ion", None, -1))
        self.comboBox_3.setItemText(4, QtWidgets.QApplication.translate("main_window", "Current", None, -1))
        self.comboBox_3.setItemText(5, QtWidgets.QApplication.translate("main_window", "E Field", None, -1))
        self.groupBox_6.setTitle(QtWidgets.QApplication.translate("main_window", "Substance", None, -1))
        self.label_72.setText(QtWidgets.QApplication.translate("main_window", "Name:", None, -1))
        self.groupBox_7.setTitle(QtWidgets.QApplication.translate("main_window", "Reaction", None, -1))
        self.label_71.setText(QtWidgets.QApplication.translate("main_window", "Name:", None, -1))
        self.groupBox_8.setTitle(QtWidgets.QApplication.translate("main_window", "Transporter", None, -1))
        self.label_70.setText(QtWidgets.QApplication.translate("main_window", "Name:", None, -1))
        self.groupBox_9.setTitle(QtWidgets.QApplication.translate("main_window", "Channel (Network)", None, -1))
        self.label_69.setText(QtWidgets.QApplication.translate("main_window", "Name:", None, -1))
        self.groupBox_10.setTitle(QtWidgets.QApplication.translate("main_window", "Modulator", None, -1))
        self.label_68.setText(QtWidgets.QApplication.translate("main_window", "Name:", None, -1))
        self.sim_run_player.setToolTip(QtWidgets.QApplication.translate("main_window", "Display and control the state of the currently queued simulation phase.", None, -1))
        self.sim_run_player.setTitle(QtWidgets.QApplication.translate("main_window", "Phase Player", None, -1))
        self.sim_run_player_progress.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>Percentage completed of the currently running simulation phase (if any).</p></body></html>", None, -1))
        self.sim_run_player_status.setToolTip(QtWidgets.QApplication.translate("main_window", "Synopsis of the currently queued simulation phase (if any).", None, -1))
        self.sim_run_player_status.setText(QtWidgets.QApplication.translate("main_window", "[insert phase status here]", None, -1))
        self.sim_run_player_substatus_group.setToolTip(QtWidgets.QApplication.translate("main_window", "Details of the currently queued simulation phase (if any).", None, -1))
        self.sim_run_player_substatus.setText(QtWidgets.QApplication.translate("main_window", "[insert phase substatus here]", None, -1))
        self.sim_run_player_toolbar .setToolTip(QtWidgets.QApplication.translate("main_window", "Control the state of the currently queued simulation phase.", None, -1))
        self.sim_run_queue_group.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>Queue (i.e., ordered list) of all simulation phases to be iteratively modelled and/or exported when the <img src=\":/icon/open_iconic/media-play.svg\"/> button is clicked. </p></body></html>", None, -1))
        self.sim_run_queue_group.setTitle(QtWidgets.QApplication.translate("main_window", "Phase Playlist", None, -1))
        self.sim_run_queue_init.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>The <span style=\" text-decoration: underline;\">initialization</span> phase calculates steady-state ion concentrations needed by the following <span style=\" text-decoration: underline;\">simulation</span> phase from the cell cluster generated by the prior <span style=\" text-decoration: underline;\">seed</span> phase.</p></body></html>", None, -1))
        self.sim_run_queue_init.setText(QtWidgets.QApplication.translate("main_window", "Initialization", None, -1))
        self.sim_run_queue_sim_export.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>Queue the <span style=\" text-decoration: underline;\">simulation</span> phase to be exported when the <img src=\":/icon/open_iconic/media-play.svg\"/> button is clicked.</p><p>Exporting this phase saves all publication-quality results (e.g., plots, animations, comma-separated value files) enabled for this phase.</p></body></html>", None, -1))
        self.sim_run_queue_sim_model.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>Queue the <span style=\" text-decoration: underline;\">simulation</span> phase to be modelled when the <img src=\":/icon/open_iconic/media-play.svg\"/> button is clicked.</p><p>Modelling this phase simulates all non-steady-state phenomena (e.g., bioelectric fields, currents, ion concentrations) for the cell cluster.</p></body></html>", None, -1))
        self.sim_run_queue_sim_model_lock.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>When locked, the <span style=\" text-decoration: underline;\">simulation</span> phase may <span style=\" font-style:italic;\">not</span> be queued for modelling. (<span style=\" font-style:italic;\">This phase may always be queued for exporting, however.</span>)</p><p>This safety measure prevents accidental deletion of either the simulation generated by this phase or subsequent results requiring this simulation.</p></body></html>", None, -1))
        self.sim_run_queue_seed.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>The <span style=\" text-decoration: underline;\">seed</span> phase generates the cell cluster needed by the following <span style=\" text-decoration: underline;\">initialization</span> phase from a pseudo-random Voronoi lattice.</p></body></html>", None, -1))
        self.sim_run_queue_seed.setText(QtWidgets.QApplication.translate("main_window", "Seed", None, -1))
        self.sim_run_queue_head_export.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>Whether or not to queue each simulation phase to be exported when the <img src=\":/icon/open_iconic/media-play.svg\"/> button is clicked.</p><p>Exporting a phase saves all publication-quality results (e.g., plots, animations, comma-separated value files) enabled for that phase.</p><p>Exporting a phase requires that phase be modelled first.</p></body></html>", None, -1))
        self.sim_run_queue_head_export.setText(QtWidgets.QApplication.translate("main_window", "Export?", None, -1))
        self.sim_run_queue_seed_model.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>Queue the <span style=\" text-decoration: underline;\">seed</span> phase to be modelled when the <img src=\":/icon/open_iconic/media-play.svg\"/> button is clicked.</p><p>Modelling this phase generates a new cell cluster from a pseudo-random Voronoi lattice.</p></body></html>", None, -1))
        self.sim_run_queue_seed_model_lock.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>When locked, the <span style=\" text-decoration: underline;\">seed</span> phase may <span style=\" font-style:italic;\">not</span> be queued for modelling. (<span style=\" font-style:italic;\">This phase may always be queued for exporting, however.</span>)</p><p>This safety measure prevents accidental deletion of either the cell cluster generated by this phase or subsequent results requiring this cell cluster.</p></body></html>", None, -1))
        self.sim_run_queue_init_export.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>Queue the <span style=\" text-decoration: underline;\">initialization</span> phase to be exported when the <img src=\":/icon/open_iconic/media-play.svg\"/> button is clicked.</p><p>Exporting this phase saves all publication-quality results (e.g., plots, animations, comma-separated value files) enabled for this phase.</p></body></html>", None, -1))
        self.sim_run_queue_init_model.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>Queue the <span style=\" text-decoration: underline;\">initialization</span> phase to be modelled when the <img src=\":/icon/open_iconic/media-play.svg\"/> button is clicked.</p><p>Modelling this phase calculates steady-state ion concentrations for the cell cluster.</p></body></html>", None, -1))
        self.sim_run_queue_init_model_lock.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>When locked, the <span style=\" text-decoration: underline;\">initialization</span> phase may <span style=\" font-style:italic;\">not</span> be queued for modelling. (<span style=\" font-style:italic;\">This phase may always be queued for exporting, however.</span>)</p><p>This safety measure prevents accidental deletion of either the initialization generated by this phase or subsequent results requiring this initialization.</p></body></html>", None, -1))
        self.sim_run_queue_init_index.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>The <span style=\" text-decoration: underline;\">initialization</span> phase is the <span style=\" font-weight:600;\">second</span> of <span style=\" font-weight:600;\">three</span> phases needed to fully model this simulation.</p></body></html>", None, -1))
        self.sim_run_queue_init_index.setText(QtWidgets.QApplication.translate("main_window", "2.", None, -1))
        self.sim_run_queue_head_model.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>Whether or not to queue each simulation phase to be modelled when the <img src=\":/icon/open_iconic/media-play.svg\"/> button is clicked.</p><p>Modelling a phase generates all simulation data needed both by the next phase <span style=\" font-style:italic;\">and</span> by all exports exportable from that phase. For example, modelling the <span style=\" text-decoration: underline;\">seed</span> phase generates all simulation data needed both by the <span style=\" text-decoration: underline;\">initialization</span> phase <span style=\" font-style:italic;\">and</span> by all exports exportable from the <span style=\" text-decoration: underline;\">seed</span> phase.</p><p>Modelling this simulation in full requires modelling the <span style=\" text-decoration: underline;\">seed</span>, <span style=\" text-decoration: underline;\">initialization</span>, <span style=\" font-style:italic;\">and </span><span style=\" text-decoration: underline;\">simulation</span> phases.</p></body></html>", None, -1))
        self.sim_run_queue_head_model.setText(QtWidgets.QApplication.translate("main_window", "Model?", None, -1))
        self.sim_run_queue_sim_index.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>The <span style=\" text-decoration: underline;\">simulation</span> phase is the <span style=\" font-weight:600;\">third</span> of <span style=\" font-weight:600;\">three</span> phases needed to fully model this simulation.</p></body></html>", None, -1))
        self.sim_run_queue_sim_index.setText(QtWidgets.QApplication.translate("main_window", "3.", None, -1))
        self.sim_run_queue_sim.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>The <span style=\" text-decoration: underline;\">simulation</span> phase simulates all non-steady-state phenomena (e.g., bioelectric fields, currents, ion concentrations) from the steady-state ion concentrations calculated by the prior <span style=\" text-decoration: underline;\">initialization</span> phase.</p></body></html>", None, -1))
        self.sim_run_queue_sim.setText(QtWidgets.QApplication.translate("main_window", "Simulation", None, -1))
        self.sim_run_queue_seed_index.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>The <span style=\" text-decoration: underline;\">seed</span> phase is the <span style=\" font-weight:600;\">first</span> of <span style=\" font-weight:600;\">three</span> phases needed to fully model this simulation.</p></body></html>", None, -1))
        self.sim_run_queue_seed_index.setText(QtWidgets.QApplication.translate("main_window", "1.", None, -1))
        self.sim_run_queue_head_phase.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>Simulation phase to be queued for subsequent modelling and/or exporting when the <img src=\":/icon/open_iconic/media-play.svg\"/> button is clicked.</p></body></html>", None, -1))
        self.sim_run_queue_head_phase.setText(QtWidgets.QApplication.translate("main_window", "Phase", None, -1))
        self.sim_run_queue_sim_status.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>Synopsis of the current state of the <span style=\" text-decoration: underline;\">simulation</span> phase.</p></body></html>", None, -1))
        self.sim_run_queue_sim_status.setText(QtWidgets.QApplication.translate("main_window", "[status]", None, -1))
        self.sim_run_queue_init_status.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>Synopsis of the current state of the <span style=\" text-decoration: underline;\">initialization</span> phase.</p></body></html>", None, -1))
        self.sim_run_queue_init_status.setText(QtWidgets.QApplication.translate("main_window", "[status]", None, -1))
        self.sim_run_queue_seed_status.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>Synopsis of the current state of the <span style=\" text-decoration: underline;\">seed</span> phase.</p></body></html>", None, -1))
        self.sim_run_queue_seed_status.setText(QtWidgets.QApplication.translate("main_window", "[status]", None, -1))
        self.sim_run_queue_head_status.setToolTip(QtWidgets.QApplication.translate("main_window", "Synopsis of the current state of each simulation phase.", None, -1))
        self.sim_run_queue_head_status.setText(QtWidgets.QApplication.translate("main_window", "Status", None, -1))
        self.sim_run_queue_seed_export_none.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>The <span style=\" text-decoration: underline;\">seed</span> phase has <span style=\" font-style:italic;\">no</span> exports and hence cannot be queued to be exported.</p><p>This differs from the <span style=\" text-decoration: underline;\">initialization</span> and <span style=\" text-decoration: underline;\">simulation</span> phases, which <span style=\" font-style:italic;\">do</span> have exports and hence can be queued to be exported.</p></body></html>", None, -1))
        self.label_23.setText(QtWidgets.QApplication.translate("main_window", "N/A", None, -1))
        self.sim_tab.setTabText(self.sim_tab.indexOf(self.sim_cmd_tab_run_area), QtWidgets.QApplication.translate("main_window", "Simulator", None, -1))
        self.sim_tab.setTabToolTip(self.sim_tab.indexOf(self.sim_cmd_tab_run_area), QtWidgets.QApplication.translate("main_window", "Interactive simulator controlling each phase (e.g., seed, initialization) of this simulation with a standard media player interface – including playback controls, progress bars, and animated video.", None, -1))
        self.menu_file.setTitle(QtWidgets.QApplication.translate("main_window", "&File", None, -1))
        self.menu_help.setTitle(QtWidgets.QApplication.translate("main_window", "&Help", None, -1))
        self.menu_edit.setTitle(QtWidgets.QApplication.translate("main_window", "&Edit", None, -1))
        self.action_open_sim.setText(QtWidgets.QApplication.translate("main_window", "&Open Simulation...", None, -1))
        self.action_open_sim.setToolTip(QtWidgets.QApplication.translate("main_window", "Open an existing simulation configuration file.", None, -1))
        self.action_open_sim.setShortcut(QtWidgets.QApplication.translate("main_window", "Ctrl+O", None, -1))
        self.action_exit.setText(QtWidgets.QApplication.translate("main_window", "&Exit", None, -1))
        self.action_exit.setToolTip(QtWidgets.QApplication.translate("main_window", "Close the current application.", None, -1))
        self.action_exit.setShortcut(QtWidgets.QApplication.translate("main_window", "Ctrl+Q", None, -1))
        self.action_save_sim.setText(QtWidgets.QApplication.translate("main_window", "&Save Simulation", None, -1))
        self.action_save_sim.setToolTip(QtWidgets.QApplication.translate("main_window", "Save the current simulation configuration file.", None, -1))
        self.action_save_sim.setShortcut(QtWidgets.QApplication.translate("main_window", "Ctrl+S", None, -1))
        self.action_about_betsee.setText(QtWidgets.QApplication.translate("main_window", "&About BETSEE...", None, -1))
        self.action_about_betsee.setIconText(QtWidgets.QApplication.translate("main_window", "About BETSEE...", None, -1))
        self.action_about_betsee.setToolTip(QtWidgets.QApplication.translate("main_window", "Display a textual synopsis of the current application.", None, -1))
        self.action_edit_prefs.setText(QtWidgets.QApplication.translate("main_window", "Pr&eferences...", None, -1))
        self.action_edit_prefs.setToolTip(QtWidgets.QApplication.translate("main_window", "Customize application settings.", None, -1))
        self.action_make_sim.setText(QtWidgets.QApplication.translate("main_window", "&New Simulation...", None, -1))
        self.action_make_sim.setToolTip(QtWidgets.QApplication.translate("main_window", "Create a new simulation configuration file with default settings.", None, -1))
        self.action_make_sim.setShortcut(QtWidgets.QApplication.translate("main_window", "Ctrl+N", None, -1))
        self.action_about_betse.setText(QtWidgets.QApplication.translate("main_window", "About &BETSE...", None, -1))
        self.action_about_betse.setToolTip(QtWidgets.QApplication.translate("main_window", "Display a textual synopsis of the underlying engine.", None, -1))
        self.action_save_sim_as.setText(QtWidgets.QApplication.translate("main_window", "Save Simulation &As...", None, -1))
        self.action_cut.setText(QtWidgets.QApplication.translate("main_window", "Cu&t", None, -1))
        self.action_cut.setToolTip(QtWidgets.QApplication.translate("main_window", "Cut the current selection to the clipboard.", None, -1))
        self.action_cut.setShortcut(QtWidgets.QApplication.translate("main_window", "Ctrl+X", None, -1))
        self.action_copy.setText(QtWidgets.QApplication.translate("main_window", "&Copy", None, -1))
        self.action_copy.setToolTip(QtWidgets.QApplication.translate("main_window", "Copy the current selection to the clipboard.", None, -1))
        self.action_copy.setShortcut(QtWidgets.QApplication.translate("main_window", "Ctrl+D", None, -1))
        self.action_paste.setText(QtWidgets.QApplication.translate("main_window", "&Paste", None, -1))
        self.action_paste.setToolTip(QtWidgets.QApplication.translate("main_window", "Paste the contents of the clipboard over the current selection.", None, -1))
        self.action_paste.setShortcut(QtWidgets.QApplication.translate("main_window", "Ctrl+V", None, -1))
        self.action_close_sim.setText(QtWidgets.QApplication.translate("main_window", "&Close Simulation", None, -1))
        self.action_close_sim.setToolTip(QtWidgets.QApplication.translate("main_window", "Close the currently open simulation.", None, -1))
        self.action_close_sim.setShortcut(QtWidgets.QApplication.translate("main_window", "Ctrl+W", None, -1))
        self.action_sim_conf_tree_item_append.setText(QtWidgets.QApplication.translate("main_window", "Append", None, -1))
        self.action_sim_conf_tree_item_append.setToolTip(QtWidgets.QApplication.translate("main_window", "Append a new item to the current list.", None, -1))
        self.action_sim_conf_tree_item_remove.setText(QtWidgets.QApplication.translate("main_window", "Remove", None, -1))
        self.action_sim_conf_tree_item_remove.setToolTip(QtWidgets.QApplication.translate("main_window", "Remove the current item from the current list.", None, -1))
        self.action_sim_run_stop_work.setText(QtWidgets.QApplication.translate("main_window", "Stop", None, -1))
        self.action_sim_run_stop_work.setToolTip(QtWidgets.QApplication.translate("main_window", "Prematurely halt the currently running simulation phase. Once stopped, rerunning this phase necessarily restarts this phase from the beginning (e.g., first sampled time step).", None, -1))
        self.action_sim_run_toggle_work.setText(QtWidgets.QApplication.translate("main_window", "Work", None, -1))
        self.action_sim_run_toggle_work.setToolTip(QtWidgets.QApplication.translate("main_window", "<html><head/><body><p>Start, pause, or unpause the currently queued simulation phase. Clicking this button either:</p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Starts this phase if currently unstarted.</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Pauses this phase if currently started at its current position (e.g., sampled time step).</li><li style=\" margin-top:0px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Unpauses this phase if currently paused from its current position (e.g., sampled time step).</li></ul></body></html>", None, -1))

from betsee.gui.simconf.guisimconftree import QBetseeSimConfTreeWidget
from betsee.gui.simconf.stack.widget.guisimconflineedit import QBetseeSimConfLineEdit, QBetseeSimConfPathnameImageLineEdit, QBetseeSimConfPathnameSubdirLineEdit
from betsee.gui.simconf.stack.widget.guisimconfcombobox import QBetseeSimConfEnumComboBox
from betsee.util.widget.stock.guiprogressbar import QBetseeProgressBar
from betsee.util.widget.stock.guilabel import QBetseeLabelImage
from betsee.gui.simtab.guisimtab import QBetseeSimmerTabWidget
from betsee.gui.simconf.stack.widget.guisimconfcheckbox import QBetseeSimConfCheckBox
from betsee.util.widget.stock.guitextedit import QBetseePlainTextEdit
from betsee.gui.simconf.stack.widget.guisimconfspinbox import QBetseeSimConfIntSpinBox, QBetseeSimConfDoubleSpinBox
from betsee.gui.simconf.stack.guisimconfstack import QBetseeSimConfStackedWidget
import betsee_rc

from PySide2.QtWidgets import QMainWindow
__BETSEE_BASE_CLASSES = (Ui_main_window, QMainWindow)
from betsee.gui.simconf.stack.widget.guisimconfradiobtn import QBetseeSimConfEnumRadioButtonGroup
